@@ -46,15 +46,17 @@ def replacestrings(source, *pairs):
 
 
 def quotecsvstr(source):
-    return '"' + \
-           replacestrings(source,
-                          ('\\"', '"'), ('"', '\\"'),
-                          ("\\\\'", "\\'"), ('\\\\n', '\\n')) + \
-           '"'
+    return (
+        '"'
+        + replacestrings(
+            source, ('\\"', '"'), ('"', '\\"'), ("\\\\'", "\\'"), ("\\\\n", "\\n")
+        )
+        + '"'
+    )
 
 
 def simplify(string):
-    return ''.join(filter(type(string).isalnum, string))
+    return "".join(filter(type(string).isalnum, string))
 
 
 class csv2po:
@@ -90,8 +92,7 @@ class csv2po:
             # do simpler matching in case things have been mangled...
             simpleid = simplify(source)
             # but check for duplicates
-            if (simpleid in self.simpleindex and
-                not (source in self.sourceindex)):
+            if simpleid in self.simpleindex and not (source in self.sourceindex):
                 # keep a list of them...
                 self.simpleindex[simpleid].append(pounit)
             else:
@@ -113,8 +114,7 @@ class csv2po:
 
     def handlecsvunit(self, csvunit):
         """handles reintegrating a csv unit into the .po file"""
-        if (len(csvunit.location.strip()) > 0 and
-            csvunit.location in self.commentindex):
+        if len(csvunit.location.strip()) > 0 and csvunit.location in self.commentindex:
             pounit = self.commentindex[csvunit.location]
         elif csvunit.source in self.sourceindex:
             pounit = self.sourceindex[csvunit.source]
@@ -122,27 +122,37 @@ class csv2po:
             thepolist = self.simpleindex[simplify(csvunit.source)]
             if len(thepolist) > 1:
                 csvfilename = getattr(self.csvfile, "filename", "(unknown)")
-                matches = "\n  ".join(["possible match: " +
-                                       pounit.source for pounit in thepolist])
-                logger.warning("%s - csv entry not unique in pofile, "
-                               "multiple matches found:\n"
-                               "  location\t%s\n"
-                               "  original\t%s\n"
-                               "  translation\t%s\n"
-                               "  %s",
-                               csvfilename, csvunit.location,
-                               csvunit.source, csvunit.target, matches)
+                matches = "\n  ".join(
+                    ["possible match: " + pounit.source for pounit in thepolist]
+                )
+                logger.warning(
+                    "%s - csv entry not unique in pofile, "
+                    "multiple matches found:\n"
+                    "  location\t%s\n"
+                    "  original\t%s\n"
+                    "  translation\t%s\n"
+                    "  %s",
+                    csvfilename,
+                    csvunit.location,
+                    csvunit.source,
+                    csvunit.target,
+                    matches,
+                )
                 self.unmatched += 1
                 return
             pounit = thepolist[0]
         else:
             csvfilename = getattr(self.csvfile, "filename", "(unknown)")
-            logger.warning("%s - csv entry not found in pofile:\n"
-                           "  location\t%s\n"
-                           "  original\t%s\n"
-                           "  translation\t%s",
-                           csvfilename, csvunit.location,
-                           csvunit.source, csvunit.target)
+            logger.warning(
+                "%s - csv entry not found in pofile:\n"
+                "  location\t%s\n"
+                "  original\t%s\n"
+                "  translation\t%s",
+                csvfilename,
+                csvunit.location,
+                csvunit.source,
+                csvunit.target,
+            )
             self.unmatched += 1
             return
         if pounit.hasplural():
@@ -158,8 +168,12 @@ class csv2po:
             elif simplify(csvunit.source) == simplify(pluralid):
                 pounit.msgstr[1] = csvunit.target
             else:
-                logger.warning("couldn't work out singular/plural: %r, %r, %r",
-                               csvunit.source, singularid, pluralid)
+                logger.warning(
+                    "couldn't work out singular/plural: %r, %r, %r",
+                    csvunit.source,
+                    singularid,
+                    pluralid,
+                )
                 self.unmatched += 1
                 return
         else:
@@ -177,16 +191,16 @@ class csv2po:
             mergemode = True
         if self.pofile.units and self.pofile.units[0].isheader():
             targetheader = self.pofile.units[0]
-            self.pofile.updateheader(content_type="text/plain; charset=UTF-8",
-                                     content_transfer_encoding="8bit")
+            self.pofile.updateheader(
+                content_type="text/plain; charset=UTF-8",
+                content_transfer_encoding="8bit",
+            )
         else:
-            targetheader = self.pofile.makeheader(charset="UTF-8",
-                                                  encoding="8bit")
-        targetheader.addnote("extracted from %s" % self.csvfile.filename,
-                             "developer")
+            targetheader = self.pofile.makeheader(charset="UTF-8", encoding="8bit")
+        targetheader.addnote("extracted from %s" % self.csvfile.filename, "developer")
         mightbeheader = True
         for csvunit in self.csvfile.units:
-            #if self.charset is not None:
+            # if self.charset is not None:
             #    csvunit.source = csvunit.source.decode(self.charset)
             #    csvunit.target = csvunit.target.decode(self.charset)
             if mightbeheader:
@@ -194,8 +208,10 @@ class csv2po:
                 mightbeheader = False
                 if csvunit.match_header():
                     continue
-                if (len(csvunit.location.strip()) == 0 and
-                    csvunit.source.find("Content-Type:") != -1):
+                if (
+                    len(csvunit.location.strip()) == 0
+                    and csvunit.source.find("Content-Type:") != -1
+                ):
                     continue
             if mergemode:
                 self.handlecsvunit(csvunit)
@@ -206,8 +222,14 @@ class csv2po:
         return self.pofile
 
 
-def convertcsv(inputfile, outputfile, templatefile, charset=None,
-               columnorder=None, duplicatestyle="msgctxt"):
+def convertcsv(
+    inputfile,
+    outputfile,
+    templatefile,
+    charset=None,
+    columnorder=None,
+    duplicatestyle="msgctxt",
+):
     """reads in inputfile using csvl10n, converts using csv2po, writes to
     outputfile
     """
@@ -216,8 +238,9 @@ def convertcsv(inputfile, outputfile, templatefile, charset=None,
         convertor = csv2po(charset=charset, duplicatestyle=duplicatestyle)
     else:
         templatestore = po.pofile(templatefile)
-        convertor = csv2po(templatestore, charset=charset,
-                           duplicatestyle=duplicatestyle)
+        convertor = csv2po(
+            templatestore, charset=charset, duplicatestyle=duplicatestyle
+        )
     outputstore = convertor.convertstore(inputstore)
     if outputstore.isempty():
         return 0
@@ -227,25 +250,35 @@ def convertcsv(inputfile, outputfile, templatefile, charset=None,
 
 def main(argv=None):
     from translate.convert import convert
+
     formats = {
         ("csv", "po"): ("po", convertcsv),
         ("csv", "pot"): ("po", convertcsv),
         ("csv", None): ("po", convertcsv),
     }
-    parser = convert.ConvertOptionParser(formats, usetemplates=True,
-                                         usepots=True,
-                                         description=__doc__)
+    parser = convert.ConvertOptionParser(
+        formats, usetemplates=True, usepots=True, description=__doc__
+    )
     parser.add_option(
-        "", "--charset", dest="charset", default=None,
-        help="set charset to decode from csv files", metavar="CHARSET")
+        "",
+        "--charset",
+        dest="charset",
+        default=None,
+        help="set charset to decode from csv files",
+        metavar="CHARSET",
+    )
     parser.add_option(
-        "", "--columnorder", dest="columnorder", default=None,
-        help="specify the order and position of columns (location,source,target)")
+        "",
+        "--columnorder",
+        dest="columnorder",
+        default=None,
+        help="specify the order and position of columns (location,source,target)",
+    )
     parser.add_duplicates_option()
     parser.passthrough.append("charset")
     parser.passthrough.append("columnorder")
     parser.run(argv)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
