@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2005, 2006 Zuza Software Foundation
 #
@@ -26,8 +25,7 @@ for examples and usage instructions.
 from translate.storage import po, poxliff
 
 
-class po2xliff(object):
-
+class po2xliff:
     def convertunit(self, outputstore, inputunit, filename):
         """creates a transunit node"""
         source = inputunit.source
@@ -37,29 +35,35 @@ class po2xliff(object):
         else:
             unit = outputstore.addsourceunit(source, filename, True)
             unit.target = target
-            #Explicitly marking the fuzzy state will ensure that normal (translated)
-            #units in the PO file end up as approved in the XLIFF file.
+            # Explicitly marking the fuzzy state will ensure that normal (translated)
+            # units in the PO file end up as approved in the XLIFF file.
             if target:
                 unit.markfuzzy(inputunit.isfuzzy())
             else:
                 unit.markapproved(False)
 
-            #Handle #: location comments
+            # Handle #: location comments
             for location in inputunit.getlocations():
-                unit.createcontextgroup("po-reference", self.contextlist(location), purpose="location")
+                unit.createcontextgroup(
+                    "po-reference", self.contextlist(location), purpose="location"
+                )
 
-            #Handle #. automatic comments
+            # Handle #. automatic comments
             comment = inputunit.getnotes("developer")
             if comment:
-                unit.createcontextgroup("po-entry", [("x-po-autocomment", comment)], purpose="information")
+                unit.createcontextgroup(
+                    "po-entry", [("x-po-autocomment", comment)], purpose="information"
+                )
                 unit.addnote(comment, origin="developer")
 
-            #TODO: x-format, etc.
+            # TODO: x-format, etc.
 
-        #Handle # other comments
+        # Handle # other comments
         comment = inputunit.getnotes("translator")
         if comment:
-            unit.createcontextgroup("po-entry", [("x-po-trancomment", comment)], purpose="information")
+            unit.createcontextgroup(
+                "po-entry", [("x-po-trancomment", comment)], purpose="information"
+            )
             unit.addnote(comment, origin="po-translator")
 
         return unit
@@ -85,7 +89,7 @@ class po2xliff(object):
         for inputunit in inputstore.units:
             if inputunit.isblank():
                 continue
-            transunitnode = self.convertunit(outputstore, inputunit, filename)
+            self.convertunit(outputstore, inputunit, filename)
         return bytes(outputstore)
 
 
@@ -102,16 +106,18 @@ def convertpo(inputfile, outputfile, templatefile):
 
 def main(argv=None):
     from translate.convert import convert
-    formats = {
-        "po": ("xlf", convertpo),
-        ("po", "xlf"): ("xlf", convertpo),
-        "po": ("xliff", convertpo),
-        ("po", "xliff"): ("xliff", convertpo),
-    }
-    parser = convert.ConvertOptionParser(formats, usetemplates=True,
-                                         description=__doc__)
+
+    formats = (
+        ("po", ("xlf", convertpo)),
+        (("po", "xlf"), ("xlf", convertpo)),
+        ("po", ("xliff", convertpo)),
+        (("po", "xliff"), ("xliff", convertpo)),
+    )
+    parser = convert.ConvertOptionParser(
+        formats, usetemplates=True, description=__doc__
+    )
     parser.run(argv)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
