@@ -5,7 +5,6 @@ from translate.storage import po
 
 
 class TestPhp2PO:
-
     def php2po(self, phpsource, phptemplate=None):
         """helper that converts .php source to po source without requiring files"""
         inputfile = BytesIO(phpsource.encode())
@@ -60,7 +59,7 @@ class TestPhp2PO:
     def test_convertphptemplate(self):
         """checks that the convertphp function is working with template"""
         phpsource = """$_LANG['simple'] = 'entry';"""
-        phptemplate = '''$_LANG['simple'] = 'source';'''
+        phptemplate = """$_LANG['simple'] = 'source';"""
         posource = self.convertphp(phpsource, phptemplate)
         pofile = po.pofile(BytesIO(posource))
         pounit = self.singleelement(pofile)
@@ -70,7 +69,7 @@ class TestPhp2PO:
     def test_convertphpmissing(self):
         """checks that the convertphp function is working with missing key"""
         phpsource = """$_LANG['simple'] = 'entry';"""
-        phptemplate = '''$_LANG['missing'] = 'source';'''
+        phptemplate = """$_LANG['missing'] = 'source';"""
         posource = self.convertphp(phpsource, phptemplate)
         pofile = po.pofile(BytesIO(posource))
         pounit = self.singleelement(pofile)
@@ -79,21 +78,21 @@ class TestPhp2PO:
 
     def test_convertphpempty(self):
         """checks that the convertphp function is working with empty template"""
-        phpsource = ''
-        phptemplate = ''
+        phpsource = ""
+        phptemplate = ""
         posource = self.convertphp(phpsource, phptemplate, 0)
         pofile = po.pofile(BytesIO(posource))
         assert len(pofile.units) == 0
 
     def test_unicode(self):
         """checks that unicode entries convert properly"""
-        unistring = 'Norsk bokm\u00E5l'
+        unistring = "Norsk bokm\u00E5l"
         phpsource = """$lang['nb'] = '%s';""" % unistring
         pofile = self.php2po(phpsource)
         pounit = self.singleelement(pofile)
         print(repr(pofile.units[0].target))
         print(repr(pounit.source))
-        assert pounit.source == 'Norsk bokm\u00E5l'
+        assert pounit.source == "Norsk bokm\u00E5l"
 
     def test_multiline(self):
         """checks that multiline enties can be parsed"""
@@ -106,8 +105,8 @@ reduce the number of cached connections.';"""
 
     def test_comments_before(self):
         """test to ensure that we take comments from .php and place them in .po"""
-        phpsource = '''/* Comment */
-$lang['prefPanel-smime'] = 'Security';'''
+        phpsource = """/* Comment */
+$lang['prefPanel-smime'] = 'Security';"""
         pofile = self.php2po(phpsource)
         pounit = self.singleelement(pofile)
         assert pounit.getnotes("developer") == "/* Comment */"
@@ -115,7 +114,7 @@ $lang['prefPanel-smime'] = 'Security';'''
 
     def test_emptyentry(self):
         """checks that empty definitions survives into po file"""
-        phpsource = '''/* comment */\n$lang['credit'] = '';'''
+        phpsource = """/* comment */\n$lang['credit'] = '';"""
         pofile = self.php2po(phpsource)
         pounit = self.singleelement(pofile)
         assert pounit.getlocations() == ["$lang['credit']"]
@@ -125,7 +124,7 @@ $lang['prefPanel-smime'] = 'Security';'''
 
     def test_hash_comment_with_equals(self):
         """Check that a # comment with = in it doesn't confuse us. Bug 1298."""
-        phpsource = '''# inside alt= stuffies\n$variable = 'stringy';'''
+        phpsource = """# inside alt= stuffies\n$variable = 'stringy';"""
         pofile = self.php2po(phpsource)
         pounit = self.singleelement(pofile)
         assert pounit.getlocations() == ["$variable"]
@@ -134,8 +133,8 @@ $lang['prefPanel-smime'] = 'Security';'''
 
     def test_emptyentry_translated(self):
         """checks that if we translate an empty definition it makes it into the PO"""
-        phptemplate = '''$lang['credit'] = '';'''
-        phpsource = '''$lang['credit'] = 'Translators Names';'''
+        phptemplate = """$lang['credit'] = '';"""
+        phpsource = """$lang['credit'] = 'Translators Names';"""
         pofile = self.php2po(phpsource, phptemplate)
         pounit = self.singleelement(pofile)
         assert pounit.getlocations() == ["$lang['credit']"]
@@ -145,40 +144,40 @@ $lang['prefPanel-smime'] = 'Security';'''
     def test_newlines_in_value(self):
         """check that we can carry newlines that appear in the entry value into the PO"""
         # Single quotes - \n is not a newline
-        phpsource = r'''$lang['name'] = 'value1\nvalue2';'''
+        phpsource = r"""$lang['name'] = 'value1\nvalue2';"""
         pofile = self.php2po(phpsource)
         unit = self.singleelement(pofile)
         assert unit.source == r"value1\nvalue2"
         # Double quotes - \n is a newline
-        phpsource = r'''$lang['name'] = "value1\nvalue2";'''
+        phpsource = r"""$lang['name'] = "value1\nvalue2";"""
         pofile = self.php2po(phpsource)
         unit = self.singleelement(pofile)
         assert unit.source == "value1\nvalue2"
 
     def test_spaces_in_name(self):
         """checks that if we have spaces in the name we create a good PO with no spaces"""
-        phptemplate = '''$lang[ 'credit' ] = 'Something';'''
-        phpsource = '''$lang[ 'credit' ] = 'n Ding';'''
+        phptemplate = """$lang[ 'credit' ] = 'Something';"""
+        phpsource = """$lang[ 'credit' ] = 'n Ding';"""
         pofile = self.php2po(phpsource, phptemplate)
         pounit = self.singleelement(pofile)
         assert pounit.getlocations() == ["$lang[ 'credit' ]"]
 
     def test_named_array(self):
-        phptemplate = '''$strings = array(\n'id-1' => 'source-1',\n);'''
-        phpsource = '''$strings = array(\n'id-1' => 'target-1',\n);'''
+        phptemplate = """$strings = array(\n'id-1' => 'source-1',\n);"""
+        phpsource = """$strings = array(\n'id-1' => 'target-1',\n);"""
         pofile = self.php2po(phpsource, phptemplate)
         pounit = self.singleelement(pofile)
         assert pounit.getlocations() == ["$strings->'id-1'"]
 
     def test_unnamed_array(self):
-        phptemplate = '''return array(\n'id-1' => 'source-1',\n);'''
-        phpsource = '''return array(\n'id-1' => 'target-1',\n);'''
+        phptemplate = """return array(\n'id-1' => 'source-1',\n);"""
+        phpsource = """return array(\n'id-1' => 'target-1',\n);"""
         pofile = self.php2po(phpsource, phptemplate)
         pounit = self.singleelement(pofile)
         assert pounit.getlocations() == ["return->'id-1'"]
 
     def test_named_nested_arrays(self):
-        phptemplate = '''$strings = array(
+        phptemplate = """$strings = array(
             'name1' => 'source1',
             'list1' => array(
                 'l1' => 'source_l1_1',
@@ -191,8 +190,8 @@ $lang['prefPanel-smime'] = 'Security';'''
                 'l3' => 'source_l2_3',
             ),
             'name2' => 'source2',
-        );'''
-        phpsource = '''$strings = array(
+        );"""
+        phpsource = """$strings = array(
             'name1' => 'target1',
             'list1' => array(
                 'l1' => 'target_l1_1',
@@ -205,7 +204,7 @@ $lang['prefPanel-smime'] = 'Security';'''
                 'l3' => 'target_l2_3',
             ),
             'name2' => 'target2',
-        );'''
+        );"""
         pofile = self.php2po(phpsource, phptemplate)
         expected = {
             "$strings->'name1'": ("source1", "target1"),
@@ -217,12 +216,13 @@ $lang['prefPanel-smime'] = 'Security';'''
             "$strings->'list2'->'l3'": ("source_l2_3", "target_l2_3"),
             "$strings->'name2'": ("source2", "target2"),
         }
-        for pounit in [x for x in pofile.units if x.source != '']:
-            assert ((pounit.source, pounit.target) ==
-                    expected.get(pounit.getlocations()[0]))
+        for pounit in [x for x in pofile.units if x.source != ""]:
+            assert (pounit.source, pounit.target) == expected.get(
+                pounit.getlocations()[0]
+            )
 
     def test_unnamed_nested_arrays(self):
-        phptemplate = '''return array(
+        phptemplate = """return array(
             'name1' => 'source1',
             'list1' => array(
                 'l1' => 'source_l1_1',
@@ -235,8 +235,8 @@ $lang['prefPanel-smime'] = 'Security';'''
                 'l3' => 'source_l2_3',
             ),
             'name2' => 'source2',
-        );'''
-        phpsource = '''return array  (
+        );"""
+        phpsource = """return array  (
             'name1' => 'target1',
             'list1' => array(
                 'l1' => 'target_l1_1',
@@ -249,7 +249,7 @@ $lang['prefPanel-smime'] = 'Security';'''
                 'l3' => 'target_l2_3',
             ),
             'name2' => 'target2',
-        );'''
+        );"""
         pofile = self.php2po(phpsource, phptemplate)
         expected = {
             "return->'name1'": ("source1", "target1"),
@@ -261,9 +261,10 @@ $lang['prefPanel-smime'] = 'Security';'''
             "return->'list2'->'l3'": ("source_l2_3", "target_l2_3"),
             "return->'name2'": ("source2", "target2"),
         }
-        for pounit in [x for x in pofile.units if x.source != '']:
-            assert ((pounit.source, pounit.target) ==
-                    expected.get(pounit.getlocations()[0]))
+        for pounit in [x for x in pofile.units if x.source != ""]:
+            assert (pounit.source, pounit.target) == expected.get(
+                pounit.getlocations()[0]
+            )
 
 
 class TestPhp2POCommand(test_convert.TestConvertCommand, TestPhp2PO):
