@@ -1,4 +1,3 @@
-
 """Tests converting Gettext PO localization files to flat XML files"""
 
 from io import BytesIO
@@ -7,12 +6,12 @@ from translate.convert import po2flatxml, test_convert
 
 
 class TestPO2FlatXML:
-    postring = '''msgid "one"
+    postring = """msgid "one"
 msgstr "One"
 
 msgid "two"
 msgstr "Two"
-'''
+"""
 
     def _convert(self, postring, templatestring=None, **kwargs):
         """Helper that converts po source to xml target without requiring files"""
@@ -36,45 +35,45 @@ msgstr "Two"
     def test_defaults(self):
         """Test a conversion with default values."""
         actual = self._convert_to_string(self.postring)
-        expected = '''<?xml version='1.0' encoding='UTF-8'?>
+        expected = """<?xml version='1.0' encoding='UTF-8'?>
 <root>
   <str key="one">One</str>
   <str key="two">Two</str>
 </root>
-'''
+"""
         assert actual == expected
 
     def test_root_name(self):
         """Test a conversion with different root name."""
         actual = self._convert_to_string(self.postring, root="strings")
-        expected = '''<?xml version='1.0' encoding='UTF-8'?>
+        expected = """<?xml version='1.0' encoding='UTF-8'?>
 <strings>
   <str key="one">One</str>
   <str key="two">Two</str>
 </strings>
-'''
+"""
         assert actual == expected
 
     def test_value_name(self):
         """Test a conversion with different value name."""
         actual = self._convert_to_string(self.postring, value="entry")
-        expected = '''<?xml version='1.0' encoding='UTF-8'?>
+        expected = """<?xml version='1.0' encoding='UTF-8'?>
 <root>
   <entry key="one">One</entry>
   <entry key="two">Two</entry>
 </root>
-'''
+"""
         assert actual == expected
 
     def test_key(self):
         """Test a conversion with different key name."""
         actual = self._convert_to_string(self.postring, key="name")
-        expected = '''<?xml version='1.0' encoding='UTF-8'?>
+        expected = """<?xml version='1.0' encoding='UTF-8'?>
 <root>
   <str name="one">One</str>
   <str name="two">Two</str>
 </root>
-'''
+"""
         assert actual == expected
 
     def test_default_namespace(self):
@@ -83,39 +82,39 @@ msgstr "Two"
         This conversion requires a template that specifies the namespace
         as default namespace; otherwise it will be generated.
         """
-        templatestring = '''<?xml version="1.0" encoding="utf-8"?>
-<root xmlns="urn:tt:test"/>'''
-        actual = self._convert_to_string(self.postring,
-                                         templatestring=templatestring,
-                                         ns="urn:tt:test")
-        expected = '''<?xml version='1.0' encoding='UTF-8'?>
+        templatestring = """<?xml version="1.0" encoding="utf-8"?>
+<root xmlns="urn:tt:test"/>"""
+        actual = self._convert_to_string(
+            self.postring, templatestring=templatestring, ns="urn:tt:test"
+        )
+        expected = """<?xml version='1.0' encoding='UTF-8'?>
 <root xmlns="urn:tt:test">
   <str key="one">One</str>
   <str key="two">Two</str>
 </root>
-'''
+"""
         assert actual == expected
 
     def test_namespace_prefix(self):
         """Test a conversion with a namespace prefix."""
         actual = self._convert_to_string(self.postring, ns="urn:tt:test")
-        expected = '''<?xml version='1.0' encoding='UTF-8'?>
+        expected = """<?xml version='1.0' encoding='UTF-8'?>
 <ns0:root xmlns:ns0="urn:tt:test">
   <ns0:str key="one">One</ns0:str>
   <ns0:str key="two">Two</ns0:str>
 </ns0:root>
-'''
+"""
         assert actual == expected
 
     def test_indent_eight(self):
         """Test a conversion with an indent width of 8."""
         actual = self._convert_to_string(self.postring, indent=8)
-        expected = '''<?xml version='1.0' encoding='UTF-8'?>
+        expected = """<?xml version='1.0' encoding='UTF-8'?>
 <root>
         <str key="one">One</str>
         <str key="two">Two</str>
 </root>
-'''
+"""
         assert actual == expected
 
     def test_noindent(self):
@@ -123,9 +122,9 @@ msgstr "Two"
         actual = self._convert_to_string(self.postring, indent=0)
         # no indent here...
         # ...except for a trailing EOL for VCS
-        expected = '''<?xml version='1.0' encoding='UTF-8'?>
+        expected = """<?xml version='1.0' encoding='UTF-8'?>
 <root><str key="one">One</str><str key="two">Two</str></root>
-'''
+"""
         assert actual == expected
 
 
