@@ -11,14 +11,13 @@ importorskip("aeidon")
 
 
 class TestPO2Sub:
-
     def po2sub(self, posource):
         """helper that converts po source to subtitle source without requiring files"""
         inputfile = BytesIO(posource.encode())
         inputpo = po.pofile(inputfile)
         convertor = po2sub.po2sub()
         outputsub = convertor.convert_store(inputpo)
-        return outputsub.decode('utf-8')
+        return outputsub.decode("utf-8")
 
     def merge2sub(self, subsource, posource):
         """helper that merges po translations to subtitle source without requiring files"""
@@ -28,34 +27,34 @@ class TestPO2Sub:
         convertor = po2sub.po2sub(templatefile, inputpo)
         outputsub = convertor.convert_store()
         print(outputsub)
-        return outputsub.decode('utf-8')
+        return outputsub.decode("utf-8")
 
     def test_subrip(self):
         """test SubRip or .srt files."""
-        posource = '''#: 00:00:20.000-->00:00:24.400
+        posource = """#: 00:00:20.000-->00:00:24.400
 msgid "Altocumulus clouds occur between six thousand"
 msgstr "Blah blah blah blah"
 
 #: 00:00:24.600-->00:00:27.800
 msgid "and twenty thousand feet above ground level."
 msgstr "Koei koei koei koei"
-'''
-        subtemplate = '''1
+"""
+        subtemplate = """1
 00:00:20,000 --> 00:00:24,400
 Altocumulus clouds occur between six thousand
 
 2
 00:00:24,600 --> 00:00:27,800
 and twenty thousand feet above ground level.
-'''
-        subexpected = '''1
+"""
+        subexpected = """1
 00:00:20,000 --> 00:00:24,400
 Blah blah blah blah
 
 2
 00:00:24,600 --> 00:00:27,800
 Koei koei koei koei
-'''
+"""
         subfile = self.merge2sub(subtemplate, posource)
         print(subexpected)
         assert subfile == subexpected
