@@ -14,17 +14,17 @@ import os
 import sys
 
 
-sys.path.insert(0, os.path.abspath('_ext'))
-sys.path.insert(0, os.path.abspath('.'))
-sys.path.insert(0, os.path.abspath('..'))
+sys.path.insert(0, os.path.abspath("_ext"))
+sys.path.insert(0, os.path.abspath("."))
+sys.path.insert(0, os.path.abspath(".."))
 
 # -- Project information -----------------------------------------------------
 
-project = 'Translate Toolkit'
-copyright = '2002-2020, Translate'
+project = "Translate Toolkit"
+copyright = "2002-2021, Translate"
 
 # The short X.Y version.
-version = '3.2.0'
+version = "3.3.0"
 
 # The full version, including alpha/beta/rc tags
 release = version
@@ -35,32 +35,35 @@ release = version
 # extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
 # ones.
 extensions = [
-    'translate_docs',
-    'sphinx.ext.autodoc',
-    'sphinx.ext.coverage',
-    'sphinx.ext.extlinks',
-    'sphinx.ext.intersphinx',
-    'sphinx.ext.todo',
+    "translate_docs",
+    "sphinx.ext.autodoc",
+    "sphinx.ext.coverage",
+    "sphinx.ext.extlinks",
+    "sphinx.ext.intersphinx",
+    "sphinx.ext.todo",
 ]
 
 # Add any paths that contain templates here, relative to this directory.
-templates_path = ['_templates']
+templates_path = ["_templates"]
 
 # List of patterns, relative to source directory, that match files and
 # directories to ignore when looking for source files.
 # This pattern also affects html_static_path and html_extra_path.
-exclude_patterns = ['_build', '_themes/README.rst', 'releases/README.rst']
+exclude_patterns = ["_build", "_themes/README.rst", "releases/README.rst"]
+
+# The master toctree document.
+master_doc = "index"
 
 # -- Missing modules --------------------------------------------------
 
 autodoc_mock_imports = [
-    'aeidon',
-    'BeautifulSoup',
-    'glib',
-    'gobject',
-    'gtk',
-    'iniparse',
-    'vobject',
+    "aeidon",
+    "BeautifulSoup",
+    "glib",
+    "gobject",
+    "gtk",
+    "iniparse",
+    "vobject",
 ]
 
 # -- Options for HTML output -------------------------------------------------
@@ -68,25 +71,25 @@ autodoc_mock_imports = [
 # The theme to use for HTML and HTML Help pages.  See the documentation for
 # a list of builtin themes.
 #
-html_theme = 'sphinx-bootstrap'
+html_theme = "sphinx-bootstrap"
 
 # Theme options are theme-specific and customize the look and feel of a theme
 # further.  For a list of options available for each theme, see the
 # documentation.
 html_theme_options = {
-    'nosidebar': True,
+    "nosidebar": True,
 }
 
 # Add any paths that contain custom themes here, relative to this directory.
-html_theme_path = ['_themes']
+html_theme_path = ["_themes"]
 
 # Add any paths that contain custom static files (such as style sheets) here,
 # relative to this directory. They are copied after the builtin static files,
 # so a file named "default.css" will overwrite the builtin "default.css".
-html_static_path = ['_static']
+html_static_path = ["_static"]
 
 # Output file base name for HTML help builder.
-htmlhelp_basename = 'TranslateToolkitdoc'
+htmlhelp_basename = "TranslateToolkitdoc"
 
 
 # -- Options for LaTeX output -------------------------------------------------
@@ -94,10 +97,8 @@ htmlhelp_basename = 'TranslateToolkitdoc'
 latex_elements = {
     # The paper size ('letterpaper' or 'a4paper').
     #'papersize': 'letterpaper',
-
     # The font size ('10pt', '11pt' or '12pt').
     #'pointsize': '10pt',
-
     # Additional stuff for the LaTeX preamble.
     #'preamble': '',
 }
@@ -105,29 +106,34 @@ latex_elements = {
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, documentclass [howto/manual])
 latex_documents = [
-  ('index', 'TranslateToolkit.tex', 'Translate Toolkit Documentation',
-   'Translate.org.za', 'manual'),
+    (
+        "index",
+        "TranslateToolkit.tex",
+        "Translate Toolkit Documentation",
+        "Translate.org.za",
+        "manual",
+    ),
 ]
 
 # The name of an image file (relative to this directory) to place at the top of
 # the title page.
-#latex_logo = None
+# latex_logo = None
 
 # For "manual" documents, if this is true, then toplevel headings are parts,
 # not chapters.
-#latex_use_parts = False
+# latex_use_parts = False
 
 # If true, show page references after internal links.
-#latex_show_pagerefs = False
+# latex_show_pagerefs = False
 
 # If true, show URL addresses after external links.
-#latex_show_urls = False
+# latex_show_urls = False
 
 # Documents to append as an appendix to all manuals.
-#latex_appendices = []
+# latex_appendices = []
 
 # If false, no module index is generated.
-#latex_domain_indices = True
+# latex_domain_indices = True
 
 
 # -- Options for manual page output -------------------------------------------
@@ -135,12 +141,17 @@ latex_documents = [
 # One entry per manual page. List of tuples
 # (source start file, name, description, authors, manual section).
 man_pages = [
-    ('index', 'translatetoolkit', 'Translate Toolkit Documentation',
-     ['Translate.org.za'], 1)
+    (
+        "index",
+        "translatetoolkit",
+        "Translate Toolkit Documentation",
+        ["Translate.org.za"],
+        1,
+    )
 ]
 
 # If true, show URL addresses after external links.
-#man_show_urls = False
+# man_show_urls = False
 
 
 # -- Options for Texinfo output -----------------------------------------------
@@ -149,26 +160,32 @@ man_pages = [
 # (source start file, target name, title, author,
 #  dir menu entry, description, category)
 texinfo_documents = [
-  ('index', 'TranslateToolkit', 'Translate Toolkit Documentation',
-   'Translate.org.za', 'TranslateToolkit', 'One line description of project.',
-   'Miscellaneous'),
+    (
+        "index",
+        "TranslateToolkit",
+        "Translate Toolkit Documentation",
+        "Translate.org.za",
+        "TranslateToolkit",
+        "One line description of project.",
+        "Miscellaneous",
+    ),
 ]
 
 # Documents to append as an appendix to all manuals.
-#texinfo_appendices = []
+# texinfo_appendices = []
 
 # If false, no module index is generated.
-#texinfo_domain_indices = True
+# texinfo_domain_indices = True
 
 # How to display URL addresses: 'footnote', 'no', or 'inline'.
-#texinfo_show_urls = 'footnote'
+# texinfo_show_urls = 'footnote'
 
 
 # -- Coverage checker options -------------------------------------------------
 
 coverage_ignore_modules = []
 
-coverage_ignore_functions = ['main']
+coverage_ignore_functions = ["main"]
 
 coverage_ignore_classes = []
 
@@ -177,11 +194,14 @@ coverage_write_headline = False
 # -- Options for intersphinx extension ---------------------------------------
 
 intersphinx_mapping = {
-    'python': ('https://docs.python.org/3.8', None),
-    'pytest': ('https://docs.pytest.org/en/latest/', None),
-    'django': ('http://django.readthedocs.org/en/latest/', None),
-    'pootle': ('http://docs.translatehouse.org/projects/pootle/en/latest/', None),
-    'guide': ('http://docs.translatehouse.org/projects/localization-guide/en/latest/', None),
+    "python": ("https://docs.python.org/3.9", None),
+    "pytest": ("https://docs.pytest.org/en/latest/", None),
+    "django": ("http://django.readthedocs.org/en/latest/", None),
+    "pootle": ("http://docs.translatehouse.org/projects/pootle/en/latest/", None),
+    "guide": (
+        "http://docs.translatehouse.org/projects/localization-guide/en/latest/",
+        None,
+    ),
 }
 
 
@@ -189,17 +209,16 @@ intersphinx_mapping = {
 
 extlinks = {
     # :role: (URL, prefix)
-    'issue': ('https://github.com/translate/translate/issues/%s',
-              'issue '),
-    'man': ('http://linux.die.net/man/1/%s', ''),
-    'wiki': ('http://translate.sourceforge.net/wiki/%s', ''),
-    'wp': ('http://en.wikipedia.org/wiki/%s', ''),
+    "issue": ("https://github.com/translate/translate/issues/%s", "issue "),
+    "man": ("http://linux.die.net/man/1/%s", ""),
+    "wiki": ("http://translate.sourceforge.net/wiki/%s", ""),
+    "wp": ("http://en.wikipedia.org/wiki/%s", ""),
 }
 
 # -- Options for Linkcheck -------------------------------------------------
 
 # Add regex's here for links that should be ignored.
 linkcheck_ignore = [
-    'http://your_server.com/filename.html',  # Example URL
-    '.*localhost.*',
+    "http://your_server.com/filename.html",  # Example URL
+    ".*localhost.*",
 ]
