@@ -33,18 +33,28 @@ class km(common.Common):
     khmerpunc = "។៕៖៘"
     """These marks are only used for Khmer."""
 
-    punctuation = "".join([common.Common.commonpunc, common.Common.quotes,
-                           common.Common.miscpunc, khmerpunc])
+    punctuation = "".join(
+        [
+            common.Common.commonpunc,
+            common.Common.quotes,
+            common.Common.miscpunc,
+            khmerpunc,
+        ]
+    )
 
     sentenceend = "!?…។៕៘"
 
-    sentencere = re.compile(r"""(?s)    #make . also match newlines
+    sentencere = re.compile(
+        r"""(?s)    #make . also match newlines
                             .*?         #anything, but match non-greedy
                             [%s]        #the puntuation for sentence ending
                             \s+         #the spacing after the puntuation
                             (?=[^a-z\d])#lookahead that next part starts with caps
-                            """ % sentenceend, re.VERBOSE)
-    #\u00a0 is non-breaking space
+                            """
+        % sentenceend,
+        re.VERBOSE,
+    )
+    # \u00a0 is non-breaking space
     puncdict = {
         ".": "\u00a0។",
         ":": "\u00a0៖",
@@ -53,7 +63,7 @@ class km(common.Common):
     }
 
     ignoretests = {
-        'all': ["simplecaps", "startcaps"],
+        "all": ["simplecaps", "startcaps"],
     }
 
     mozilla_nplurals = 2
