@@ -1,5 +1,3 @@
-#!/usr/bin/env python2
-# -*- coding: utf-8 -*-
 #
 # Copyright 2013 Zuza Software Foundation
 #
@@ -23,10 +21,13 @@
 .. seealso:: http://en.wikipedia.org/wiki/Chinese_language
 """
 
+
 from translate.lang.zh import zh
 
 
 class zh_cn(zh):
-    specialchars = u"←→↔×÷©…—‘’“”【】《》"
+    specialchars = "←→↔×÷©…—‘’“”【】《》"
 
-    ignoretests = ["startcaps", "simplecaps", "acronyms"]
+    ignoretests = {
+        "all": ["acronyms", "simplecaps", "startcaps"],
+    }
