@@ -31,20 +31,24 @@ from translate.misc import progressbar
 
 
 class ProgressBar:
-    progress_types = OrderedDict([
-        ("dots", progressbar.DotsProgressBar),
-        ("none", progressbar.NoProgressBar),
-        ("bar", progressbar.HashProgressBar),
-        ("names", progressbar.MessageProgressBar),
-        ("verbose", progressbar.VerboseProgressBar),
-    ])
+    progress_types = OrderedDict(
+        [
+            ("dots", progressbar.DotsProgressBar),
+            ("none", progressbar.NoProgressBar),
+            ("bar", progressbar.HashProgressBar),
+            ("names", progressbar.MessageProgressBar),
+            ("verbose", progressbar.VerboseProgressBar),
+        ]
+    )
 
     def __init__(self, progress_type, allfiles):
         """Set up a progress bar appropriate to the progress_type and files."""
-        if progress_type in ('bar', 'verbose'):
+        if progress_type in ("bar", "verbose"):
             file_count = len(allfiles)
             self._progressbar = self.progress_types[progress_type](0, file_count)
-            logger = logging.getLogger(os.path.basename(sys.argv[0])).getChild("progress")
+            logger = logging.getLogger(os.path.basename(sys.argv[0])).getChild(
+                "progress"
+            )
             logger.setLevel(logging.INFO)
             logger.propagate = False
             handler = logging.StreamHandler()
@@ -61,7 +65,7 @@ class ProgressBar:
         self._progressbar.show(filename)
 
 
-class ManPageOption(optparse.Option, object):
+class ManPageOption(optparse.Option):
     ACTIONS = optparse.Option.ACTIONS + ("manpage",)
 
     def take_action(self, action, dest, opt, value, values, parser):
@@ -73,16 +77,16 @@ class ManPageOption(optparse.Option, object):
 
 
 class ManHelpFormatter(optparse.HelpFormatter):
-
-    def __init__(self, indent_increment=0, max_help_position=0, width=80,
-                 short_first=1):
+    def __init__(
+        self, indent_increment=0, max_help_position=0, width=80, short_first=1
+    ):
         super().__init__(indent_increment, max_help_position, width, short_first)
 
     def format_option_strings(self, option):
         """Return a comma-separated list of option strings & metavariables."""
         if option.takes_value():
             metavar = option.metavar or option.dest.upper()
-            metavar = '\\fI%s\\fP' % metavar
+            metavar = "\\fI%s\\fP" % metavar
             short_opts = [sopt + metavar for sopt in option._short_opts]
             long_opts = [lopt + "\\fR=\\fP" + metavar for lopt in option._long_opts]
         else:
@@ -94,11 +98,12 @@ class ManHelpFormatter(optparse.HelpFormatter):
         else:
             opts = long_opts + short_opts
 
-        return '\\fB%s\\fP' % ("\\fR, \\fP".join(opts))
+        return "\\fB%s\\fP" % ("\\fR, \\fP".join(opts))
 
 
 class StdoutWrapper:
-    out = sys.stdout
+    def __init__(self):
+        self.out = sys.stdout
 
     def __getattr__(self, name):
         return getattr(self.out, name)
@@ -106,7 +111,7 @@ class StdoutWrapper:
     def write(self, content):
         if isinstance(content, bytes):
             try:
-                self.out.write(content.decode('utf-8'))
+                self.out.write(content.decode("utf-8"))
             except UnicodeDecodeError:
                 self.out.write("Unable to write binary content to the terminal")
         else:
@@ -116,8 +121,9 @@ class StdoutWrapper:
 class RecursiveOptionParser(optparse.OptionParser):
     """A specialized Option Parser for recursing through directories."""
 
-    def __init__(self, formats, usetemplates=False, allowmissingtemplate=False,
-                 description=None):
+    def __init__(
+        self, formats, usetemplates=False, allowmissingtemplate=False, description=None
+    ):
         """Construct the specialized Option Parser.
 
         :type formats: Dictionary
@@ -142,9 +148,13 @@ class RecursiveOptionParser(optparse.OptionParser):
         manpage
         """
         manpageoption = ManPageOption(
-            None, "--manpage", dest="manpage",
-            default=False, action="manpage",
-            help="output a manpage based on the help")
+            None,
+            "--manpage",
+            dest="manpage",
+            default=False,
+            action="manpage",
+            help="output a manpage based on the help",
+        )
         self.define_option(manpageoption)
 
     def format_manpage(self):
@@ -154,29 +164,37 @@ class RecursiveOptionParser(optparse.OptionParser):
         formatprog = lambda x: x.replace("%prog", prog)
         formatToolkit = lambda x: x.replace("%prog", "Translate Toolkit")
         result.append('.\\" Autogenerated manpage\n')
-        result.append('.TH %s 1 "%s" "" "%s"\n' % (
-            prog, formatToolkit(self.version), formatToolkit(self.version)))
-        result.append('.SH NAME\n')
-        result.append('%s \\- %s\n' % (self.get_prog_name(),
-                                       self.description.split('\n\n')[0]))
-        result.append('.SH SYNOPSIS\n')
-        result.append('.PP\n')
+        result.append(
+            '.TH %s 1 "%s" "" "%s"\n'
+            % (prog, formatToolkit(self.version), formatToolkit(self.version))
+        )
+        result.append(".SH NAME\n")
+        result.append(
+            "{} \\- {}\n".format(
+                self.get_prog_name(), self.description.split("\n\n")[0]
+            )
+        )
+        result.append(".SH SYNOPSIS\n")
+        result.append(".PP\n")
         usage = "\\fB%prog "
         usage += " ".join([self.getusageman(option) for option in self.option_list])
         usage += "\\fP"
-        result.append('%s\n' % formatprog(usage))
-        description_lines = self.description.split('\n\n')[1:]
+        result.append("%s\n" % formatprog(usage))
+        description_lines = self.description.split("\n\n")[1:]
         if description_lines:
-            result.append('.SH DESCRIPTION\n')
-            result.append('\n\n'.join([re.sub(r'\.\. note::', 'Note:', l)
-                                       for l in description_lines]))
-        result.append('.SH OPTIONS\n')
+            result.append(".SH DESCRIPTION\n")
+            result.append(
+                "\n\n".join(
+                    [re.sub(r"\.\. note::", "Note:", l) for l in description_lines]
+                )
+            )
+        result.append(".SH OPTIONS\n")
         ManHelpFormatter().store_option_strings(self)
-        result.append('.PP\n')
+        result.append(".PP\n")
         for option in self.option_list:
-            result.append('.TP\n')
-            result.append('%s\n' % str(option).replace('-', r'\-'))
-            result.append('%s\n' % option.help.replace('-', r'\-'))
+            result.append(".TP\n")
+            result.append("%s\n" % str(option).replace("-", r"\-"))
+            result.append("%s\n" % option.help.replace("-", r"\-"))
         return "".join(result)
 
     def print_manpage(self, file=None):
@@ -190,18 +208,23 @@ class RecursiveOptionParser(optparse.OptionParser):
         each option
         """
         if usage is None:
-            self.usage = "%prog " + " ".join([self.getusagestring(option) for option in self.option_list])
+            self.usage = "%prog " + " ".join(
+                [self.getusagestring(option) for option in self.option_list]
+            )
         else:
             super().set_usage(usage)
 
     def warning(self, msg, options=None, exc_info=None):
-        """Print a warning message incorporating 'msg' to stderr and exit."""
+        """Print a warning message incorporating 'msg' to stderr."""
         if options:
             if options.errorlevel == "traceback":
-                errorinfo = "\n".join(traceback.format_exception(exc_info[0],
-                                      exc_info[1], exc_info[2]))
+                errorinfo = "\n".join(
+                    traceback.format_exception(exc_info[0], exc_info[1], exc_info[2])
+                )
             elif options.errorlevel == "exception":
-                errorinfo = "\n".join(traceback.format_exception_only(exc_info[0], exc_info[1]))
+                errorinfo = "\n".join(
+                    traceback.format_exception_only(exc_info[0], exc_info[1])
+                )
             elif options.errorlevel == "message":
                 errorinfo = str(exc_info[1])
             else:
@@ -272,13 +295,13 @@ class RecursiveOptionParser(optparse.OptionParser):
             formats = formats.items()
         for formatgroup, outputoptions in formats:
             if isinstance(formatgroup, str) or formatgroup is None:
-                formatgroup = (formatgroup, )
+                formatgroup = (formatgroup,)
             if not isinstance(formatgroup, tuple):
                 raise ValueError("formatgroups must be tuples or None/str/unicode")
             if len(formatgroup) < 1 or len(formatgroup) > 2:
                 raise ValueError("formatgroups must be tuples of length 1 or 2")
             if len(formatgroup) == 1:
-                formatgroup += (None, )
+                formatgroup += (None,)
             inputformat, templateformat = formatgroup
             if not isinstance(outputoptions, tuple) or len(outputoptions) != 2:
                 raise ValueError("output options must be tuples of length 2")
@@ -289,26 +312,42 @@ class RecursiveOptionParser(optparse.OptionParser):
                 outputformats.append(outputformat)
             if templateformat not in templateformats:
                 templateformats.append(templateformat)
-            self.outputoptions[(inputformat, templateformat)] = (outputformat, processor)
+            self.outputoptions[(inputformat, templateformat)] = (
+                outputformat,
+                processor,
+            )
         inputformathelp = self.getformathelp(self.inputformats)
         inputoption = optparse.Option(
-            "-i", "--input", dest="input",
-            default=None, metavar="INPUT",
-            help="read from INPUT in %s" % (inputformathelp))
+            "-i",
+            "--input",
+            dest="input",
+            default=None,
+            metavar="INPUT",
+            help="read from INPUT in %s" % (inputformathelp),
+        )
         inputoption.optionalswitch = True
         inputoption.required = True
         self.define_option(inputoption)
         excludeoption = optparse.Option(
-            "-x", "--exclude", dest="exclude",
-            action="append", type="string", metavar="EXCLUDE",
+            "-x",
+            "--exclude",
+            dest="exclude",
+            action="append",
+            type="string",
+            metavar="EXCLUDE",
             default=["CVS", ".svn", "_darcs", ".git", ".hg", ".bzr"],
-            help="exclude names matching EXCLUDE from input paths")
+            help="exclude names matching EXCLUDE from input paths",
+        )
         self.define_option(excludeoption)
         outputformathelp = self.getformathelp(outputformats)
         outputoption = optparse.Option(
-            "-o", "--output", dest="output",
-            default=None, metavar="OUTPUT",
-            help="write to OUTPUT in %s" % (outputformathelp))
+            "-o",
+            "--output",
+            dest="output",
+            default=None,
+            metavar="OUTPUT",
+            help="write to OUTPUT in %s" % (outputformathelp),
+        )
         outputoption.optionalswitch = True
         outputoption.required = True
         self.define_option(outputoption)
@@ -316,28 +355,40 @@ class RecursiveOptionParser(optparse.OptionParser):
             self.templateformats = templateformats
             templateformathelp = self.getformathelp(self.templateformats)
             templateoption = optparse.Option(
-                "-t", "--template",
-                dest="template", default=None, metavar="TEMPLATE",
-                help="read from TEMPLATE in %s" % (templateformathelp))
+                "-t",
+                "--template",
+                dest="template",
+                default=None,
+                metavar="TEMPLATE",
+                help="read from TEMPLATE in %s" % (templateformathelp),
+            )
             self.define_option(templateoption)
 
     def setprogressoptions(self):
         """Sets the progress options."""
         progressoption = optparse.Option(
-            None, "--progress", dest="progress", default="bar",
-            choices=list(ProgressBar.progress_types.keys()), metavar="PROGRESS",
-            help="show progress as: %s" % (", ".join(ProgressBar.progress_types)))
+            None,
+            "--progress",
+            dest="progress",
+            default="bar",
+            choices=list(ProgressBar.progress_types.keys()),
+            metavar="PROGRESS",
+            help="show progress as: %s" % (", ".join(ProgressBar.progress_types)),
+        )
         self.define_option(progressoption)
 
     def seterrorleveloptions(self):
         """Sets the errorlevel options."""
         self.errorleveltypes = ["none", "message", "exception", "traceback"]
         errorleveloption = optparse.Option(
-            None, "--errorlevel",
-            dest="errorlevel", default="message",
-            choices=self.errorleveltypes, metavar="ERRORLEVEL",
-            help="show errorlevel as: %s" % (
-                ", ".join(self.errorleveltypes)))
+            None,
+            "--errorlevel",
+            dest="errorlevel",
+            default="message",
+            choices=self.errorleveltypes,
+            metavar="ERRORLEVEL",
+            help="show errorlevel as: %s" % (", ".join(self.errorleveltypes)),
+        )
         self.define_option(errorleveloption)
 
     def getformathelp(self, formats):
@@ -350,7 +401,7 @@ class RecursiveOptionParser(optparse.OptionParser):
         else:
             return "%s formats" % (", ".join(formats))
 
-    def isrecursive(self, fileoption, filepurpose='input'):
+    def isrecursive(self, fileoption, filepurpose="input"):
         """Checks if fileoption is a recursive file."""
         if fileoption is None:
             return False
@@ -377,12 +428,16 @@ class RecursiveOptionParser(optparse.OptionParser):
             options.output = args[-1]
             args = args[:-1]
         if args:
-            self.error("You have used an invalid combination of --input, --output and freestanding args")
+            self.error(
+                "You have used an invalid combination of --input, --output and freestanding args"
+            )
         if isinstance(options.input, list) and len(options.input) == 1:
             options.input = options.input[0]
         if options.input is None:
-            self.error("You need to give an inputfile or use - for stdin ; use --help for full usage instructions")
-        elif options.input == '-':
+            self.error(
+                "You need to give an inputfile or use - for stdin ; use --help for full usage instructions"
+            )
+        elif options.input == "-":
             options.input = None
         return (options, args)
 
@@ -423,16 +478,24 @@ class RecursiveOptionParser(optparse.OptionParser):
         else:
             if self.usetemplates:
                 if inputext is None:
-                    raise ValueError("don't know what to do with input format (no file extension), no template file")
+                    raise ValueError(
+                        "don't know what to do with input format (no file extension), no template file"
+                    )
                 elif templateext is None:
-                    raise ValueError("don't know what to do with input format %s, no template file" %
-                                     (os.extsep + inputext))
+                    raise ValueError(
+                        "don't know what to do with input format %s, no template file"
+                        % (os.extsep + inputext)
+                    )
                 else:
-                    raise ValueError("don't know what to do with input format %s, template format %s" %
-                                     (os.extsep + inputext, os.extsep + templateext))
+                    raise ValueError(
+                        "don't know what to do with input format %s, template format %s"
+                        % (os.extsep + inputext, os.extsep + templateext)
+                    )
             else:
-                raise ValueError("don't know what to do with input format %s" %
-                                 (os.extsep + inputext))
+                raise ValueError(
+                    "don't know what to do with input format %s"
+                    % (os.extsep + inputext)
+                )
         if outputformat == "*":
             if inputext:
                 outputformat = inputext
@@ -442,31 +505,34 @@ class RecursiveOptionParser(optparse.OptionParser):
                 outputformat = None
             else:
                 if self.usetemplates:
-                    raise ValueError("don't know what to do with input format (no file extension), no template file")
+                    raise ValueError(
+                        "don't know what to do with input format (no file extension), no template file"
+                    )
                 else:
-                    raise ValueError("don't know what to do with input format (no file extension)")
+                    raise ValueError(
+                        "don't know what to do with input format (no file extension)"
+                    )
         return outputformat, fileprocessor
 
     def getfullinputpath(self, options, inputpath):
-        """Gets the absolute path to an input file."""
+        """Gets the full path to an input file."""
         if options.input:
             return os.path.join(options.input, inputpath)
         else:
             return inputpath
 
     def getfulloutputpath(self, options, outputpath):
-        """Gets the absolute path to an output file."""
+        """Gets the full path to an output file."""
         if options.recursiveoutput and options.output:
             return os.path.join(options.output, outputpath)
         else:
             return outputpath
 
     def getfulltemplatepath(self, options, templatepath):
-        """Gets the absolute path to a template file."""
+        """Gets the full path to a template file."""
         if not options.recursivetemplate:
             return templatepath
-        elif (templatepath is not None and
-              self.usetemplates and options.template):
+        elif templatepath is not None and self.usetemplates and options.template:
             return os.path.join(options.template, templatepath)
         else:
             return None
@@ -480,15 +546,10 @@ class RecursiveOptionParser(optparse.OptionParser):
 
     def recursiveprocess(self, options):
         """Recurse through directories and process files."""
-        if self.isrecursive(options.input, 'input') and getattr(options, "allowrecursiveinput", True):
-            if not self.isrecursive(options.output, 'output'):
-                if not options.output:
-                    self.error(optparse.OptionValueError("No output directory given"))
-                try:
-                    self.warning("Output directory does not exist. Attempting to create")
-                    os.mkdir(options.output)
-                except IOError:
-                    self.error(optparse.OptionValueError("Output directory does not exist, attempt to create failed"))
+        if self.isrecursive(options.input, "input") and getattr(
+            options, "allowrecursiveinput", True
+        ):
+            self.ensurerecursiveoutputdirexists(options)
             if isinstance(options.input, list):
                 inputfiles = self.recurseinputfilelist(options)
             else:
@@ -499,57 +560,90 @@ class RecursiveOptionParser(optparse.OptionParser):
                 options.input = os.path.dirname(options.input)
             else:
                 inputfiles = [options.input]
-        options.recursiveoutput = (self.isrecursive(options.output, 'output') and
-                                   getattr(options, "allowrecursiveoutput", True))
-        options.recursivetemplate = (self.usetemplates and
-                                     self.isrecursive(options.template, 'template') and
-                                     getattr(options, "allowrecursivetemplate", True))
+        options.recursiveoutput = self.isrecursive(
+            options.output, "output"
+        ) and getattr(options, "allowrecursiveoutput", True)
+        options.recursivetemplate = (
+            self.usetemplates
+            and self.isrecursive(options.template, "template")
+            and getattr(options, "allowrecursivetemplate", True)
+        )
+        # sort the input files to preserve the order between runs as much as possible.
+        # this makes for more merge-friendly content in single-output-file mode.
+        inputfiles.sort()
         progress_bar = ProgressBar(options.progress, inputfiles)
         for inputpath in inputfiles:
             try:
                 templatepath = self.gettemplatename(options, inputpath)
                 # If we have a recursive template, but the template doesn't
                 # have this input file, let's drop it.
-                if (options.recursivetemplate and templatepath is None and
-                    not self.allowmissingtemplate):
-                    self.warning("No template at %s. Skipping %s." %
-                                 (templatepath, inputpath))
+                if (
+                    options.recursivetemplate
+                    and templatepath is None
+                    and not self.allowmissingtemplate
+                ):
+                    self.warning(
+                        f"No template at {templatepath}. Skipping {inputpath}."
+                    )
                     continue
-                outputformat, fileprocessor = self.getoutputoptions(options, inputpath, templatepath)
+                outputformat, fileprocessor = self.getoutputoptions(
+                    options, inputpath, templatepath
+                )
                 fullinputpath = self.getfullinputpath(options, inputpath)
-                fulltemplatepath = self.getfulltemplatepath(options,
-                                                            templatepath)
+                fulltemplatepath = self.getfulltemplatepath(options, templatepath)
                 outputpath = self.getoutputname(options, inputpath, outputformat)
                 fulloutputpath = self.getfulloutputpath(options, outputpath)
                 if options.recursiveoutput and outputpath:
                     self.checkoutputsubdir(options, os.path.dirname(outputpath))
             except Exception:
-                self.warning("Couldn't handle input file %s" %
-                             inputpath, options, sys.exc_info())
+                self.warning(
+                    "Couldn't handle input file %s" % inputpath, options, sys.exc_info()
+                )
                 continue
             try:
-                success = self.processfile(fileprocessor, options,
-                                           fullinputpath, fulloutputpath,
-                                           fulltemplatepath)
+                success = self.processfile(
+                    fileprocessor,
+                    options,
+                    fullinputpath,
+                    fulloutputpath,
+                    fulltemplatepath,
+                )
             except Exception:
-                self.warning("Error processing: input %s, output %s, template %s" %
-                             (fullinputpath, fulloutputpath,
-                              fulltemplatepath), options, sys.exc_info())
+                self.warning(
+                    "Error processing: input %s, output %s, template %s"
+                    % (fullinputpath, fulloutputpath, fulltemplatepath),
+                    options,
+                    sys.exc_info(),
+                )
                 success = False
             progress_bar.report_progress(inputpath, success)
         del progress_bar
 
+    def ensurerecursiveoutputdirexists(self, options):
+        if not self.isrecursive(options.output, "output"):
+            if not options.output:
+                self.error(optparse.OptionValueError("No output directory given"))
+            try:
+                self.warning("Output directory does not exist. Attempting to create")
+                os.mkdir(options.output)
+            except OSError:
+                self.error(
+                    optparse.OptionValueError(
+                        "Output directory does not exist, attempt to create failed"
+                    )
+                )
+
     def openinputfile(self, options, fullinputpath):
         """Opens the input file."""
         if fullinputpath is None:
             return sys.stdin
-        return open(fullinputpath, 'rb')
+        return open(fullinputpath, "rb")
 
     def openoutputfile(self, options, fulloutputpath):
         """Opens the output file."""
         if fulloutputpath is None:
             return StdoutWrapper()
-        return open(fulloutputpath, 'wb')
+        return open(fulloutputpath, "wb")
 
     def opentempoutputfile(self, options, fulloutputpath):
         """Opens a temporary output file."""
@@ -567,17 +661,17 @@ class RecursiveOptionParser(optparse.OptionParser):
         """Opens the template file (if required)."""
         if fulltemplatepath is not None:
             if os.path.isfile(fulltemplatepath):
-                return open(fulltemplatepath, 'rb')
+                return open(fulltemplatepath, "rb")
             else:
                 self.warning("missing template file %s" % fulltemplatepath)
         return None
 
-    def processfile(self, fileprocessor, options, fullinputpath,
-                    fulloutputpath, fulltemplatepath):
+    def processfile(
+        self, fileprocessor, options, fullinputpath, fulloutputpath, fulltemplatepath
+    ):
         """Process an individual file."""
         inputfile = self.openinputfile(options, fullinputpath)
-        if (fulloutputpath and
-            fulloutputpath in (fullinputpath, fulltemplatepath)):
+        if fulloutputpath and fulloutputpath in (fullinputpath, fulltemplatepath):
             outputfile = self.opentempoutputfile(options, fulloutputpath)
             tempoutput = True
         else:
@@ -585,12 +679,10 @@ class RecursiveOptionParser(optparse.OptionParser):
             tempoutput = False
         templatefile = self.opentemplatefile(options, fulltemplatepath)
         passthroughoptions = self.getpassthroughoptions(options)
-        if fileprocessor(inputfile, outputfile, templatefile,
-                         **passthroughoptions):
+        if fileprocessor(inputfile, outputfile, templatefile, **passthroughoptions):
             if tempoutput:
                 self.warning("writing to temporary output...")
-                self.finalizetempoutputfile(options, outputfile,
-                                            fulloutputpath)
+                self.finalizetempoutputfile(options, outputfile, fulloutputpath)
             return True
         else:
             # remove the file if it is a file (could be stdout etc)
@@ -602,8 +694,10 @@ class RecursiveOptionParser(optparse.OptionParser):
     def mkdir(self, parent, subdir):
         """Makes a subdirectory (recursively if neccessary)."""
         if not os.path.isdir(parent):
-            raise ValueError("cannot make child directory %r if parent %r does not exist" %
-                             (subdir, parent))
+            raise ValueError(
+                "cannot make child directory %r if parent %r does not exist"
+                % (subdir, parent)
+            )
         currentpath = parent
         subparts = subdir.split(os.sep)
         for part in subparts:
@@ -645,7 +739,7 @@ class RecursiveOptionParser(optparse.OptionParser):
 
     def recurseinputfiles(self, options):
         """Recurse through directories and return files to be processed."""
-        dirstack = ['']
+        dirstack = [""]
         join = os.path.join
         inputfiles = []
         while dirstack:
@@ -736,5 +830,4 @@ class RecursiveOptionParser(optparse.OptionParser):
     def isvalidinputname(self, inputname):
         """Checks if this is a valid input filename."""
         inputbase, inputext = self.splitinputext(inputname)
-        return ((inputext in self.inputformats) or
-                ("*" in self.inputformats))
+        return (inputext in self.inputformats) or ("*" in self.inputformats)
