@@ -32,8 +32,8 @@ from translate.storage import base, lisa
 
 
 EOF = None
-WHITESPACE = ' \n\t'  # Whitespace that we collapse.
-MULTIWHITESPACE = re.compile('[ \n\t]{2}(?!\\\\n)')
+WHITESPACE = " \n\t"  # Whitespace that we collapse.
+MULTIWHITESPACE = re.compile("[ \n\t]{2}(?!\\\\n)")
 
 
 class AndroidResourceUnit(base.TranslationUnit):
@@ -60,10 +60,7 @@ class AndroidResourceUnit(base.TranslationUnit):
         super().__init__(source)
 
     def istranslatable(self):
-        return (
-            bool(self.getid())
-            and self.xmlelement.get('translatable') != 'false'
-        )
+        return bool(self.getid()) and self.xmlelement.get("translatable") != "false"
 
     def isblank(self):
         return not bool(self.getid())
@@ -86,7 +83,7 @@ class AndroidResourceUnit(base.TranslationUnit):
         """
         # Return text for empty elements
         if text is None:
-            return ''
+            return ""
 
         # We need to collapse multiple whitespace while paying
         # attention to Android's quoting and escaping.
@@ -113,10 +110,10 @@ class AndroidResourceUnit(base.TranslationUnit):
                     if not active_quote or c is EOF:
                         # Replace by a single space, will get rid of
                         # non-significant newlines/tabs etc.
-                        text[i-space_count:i] = ' '
+                        text[i - space_count : i] = " "
                         i -= space_count - 1
                         if strip and (i == 1 or c is EOF):
-                            del text[i-1]
+                            del text[i - 1]
                     space_count = 0
                 elif space_count == 1:
                     # At this point we have a single whitespace character,
@@ -125,9 +122,9 @@ class AndroidResourceUnit(base.TranslationUnit):
                     # it will be considered significant on import. So,
                     # make sure that this kind of whitespace is always a
                     # standard space.
-                    text[i-1] = ' '
+                    text[i - 1] = " "
                     if strip and not active_quote and (i == 1 or c is EOF):
-                        del text[i-1]
+                        del text[i - 1]
                     space_count = 0
                 else:
                     space_count = 0
@@ -140,13 +137,13 @@ class AndroidResourceUnit(base.TranslationUnit):
 
             # If the string is run through a formatter, it will have
             # percentage signs for String.format
-            if c == '%' and not active_escape:
+            if c == "%" and not active_escape:
                 active_percent = not active_percent
             elif not active_escape and active_percent:
                 active_percent = False
 
             # Handle escapes
-            if c == '\\':
+            if c == "\\":
                 if not active_escape:
                     active_escape = True
                 else:
@@ -165,25 +162,25 @@ class AndroidResourceUnit(base.TranslationUnit):
                         # this first so we can use the ``in`` operator
                         # in the clauses below without issue.
                         pass
-                    elif c == 'n' or c == 'N':
+                    elif c == "n" or c == "N":
                         # Remove whitespace just before newline. Most likely this is result of
                         # having real newline in the XML in front of \n.
-                        if i >= 2 and text[i-2] == " ":
+                        if i >= 2 and text[i - 2] == " ":
                             offset = 2
                         else:
                             offset = 1
-                        text[i - offset:i + 1] = '\n'  # an actual newline
+                        text[i - offset : i + 1] = "\n"  # an actual newline
                         i -= offset
-                    elif c == 't' or c == 'T':
-                        text[i-1:i+1] = '\t'  # an actual tab
+                    elif c == "t" or c == "T":
+                        text[i - 1 : i + 1] = "\t"  # an actual tab
                         i -= 1
-                    elif c == ' ':
-                        text[i-1:i+1] = ' '  # an actual space
+                    elif c == " ":
+                        text[i - 1 : i + 1] = " "  # an actual space
                         i -= 1
-                    elif c in '"\'@?':
-                        text[i-1:i] = ''  # remove the backslash
+                    elif c in "\"'@?":
+                        text[i - 1 : i] = ""  # remove the backslash
                         i -= 1
-                    elif c == 'u':
+                    elif c == "u":
                         # Unicode sequence. Android is nice enough to deal
                         # with those in a way which let's us just capture
                         # the next 4 characters and raise an error if they
@@ -194,10 +191,12 @@ class AndroidResourceUnit(base.TranslationUnit):
                         # prefixing the missing digits with zeros.
                         # Note: max(len()) is needed in the slice due to
                         # trailing ``None`` element.
-                        max_slice = min(i+5, len(text)-1)
-                        codepoint_str = "".join(text[i+1:max_slice])
+                        max_slice = min(i + 5, len(text) - 1)
+                        codepoint_str = "".join(text[i + 1 : max_slice])
                         if len(codepoint_str) < 4:
-                            codepoint_str = "0" * (4-len(codepoint_str)) + codepoint_str
+                            codepoint_str = (
+                                "0" * (4 - len(codepoint_str)) + codepoint_str
+                            )
                         try:
                             # We can't trust int() to raise a ValueError,
                             # it will ignore leading/trailing whitespace.
@@ -205,13 +204,13 @@ class AndroidResourceUnit(base.TranslationUnit):
                                 raise ValueError(codepoint_str)
                             codepoint = chr(int(codepoint_str, 16))
                         except ValueError:
-                            raise ValueError('bad unicode escape sequence')
+                            raise ValueError("bad unicode escape sequence")
 
-                        text[i-1:max_slice] = codepoint
+                        text[i - 1 : max_slice] = codepoint
                         i -= 1
                     else:
                         # All others, remove, like Android does as well.
-                        text[i-1:i+1] = ''
+                        text[i - 1 : i + 1] = ""
                         i -= 1
                     active_escape = False
 
@@ -221,7 +220,7 @@ class AndroidResourceUnit(base.TranslationUnit):
         return "".join(text[:-1])
 
     def xml_escape_space(self, matchobj):
-        return matchobj.group(0).replace('  ', r' \u0020')
+        return matchobj.group(0).replace("  ", r" \u0020")
 
     def escape(self, text, quote_wrapping_whitespaces=True):
         """Escape all the characters which need to be escaped in an Android XML
@@ -235,22 +234,24 @@ class AndroidResourceUnit(base.TranslationUnit):
         if text is None:
             return
         if len(text) == 0:
-            return ''
-        text = text.replace('\\', '\\\\')
+            return ""
+        text = text.replace("\\", "\\\\")
         # This will add non intrusive real newlines to
         # ones in translation improving readability of result
-        text = text.replace('\n', '\n\\n')
-        text = text.replace('\t', '\\t')
-        text = text.replace('\'', '\\\'')
-        text = text.replace('?', '\\?')
+        text = text.replace("\n", "\n\\n")
+        text = text.replace("\t", "\\t")
+        text = text.replace("'", "\\'")
+        text = text.replace("?", "\\?")
         text = text.replace('"', '\\"')
 
         # @ needs to be escaped at start
-        if text.startswith('@'):
-            text = '\\@' + text[1:]
+        if text.startswith("@"):
+            text = "\\@" + text[1:]
         # Quote strings with more whitespace
         multispace = MULTIWHITESPACE.findall(text)
-        if (quote_wrapping_whitespaces and (text[0] in WHITESPACE or text[-1] in WHITESPACE or multispace)):
+        if quote_wrapping_whitespaces and (
+            text[0] in WHITESPACE or text[-1] in WHITESPACE or multispace
+        ):
             return '"%s"' % text
         # In xml multispace
         if not quote_wrapping_whitespaces and multispace:
@@ -283,15 +284,19 @@ class AndroidResourceUnit(base.TranslationUnit):
 
             # Grab root text (using a temporary xml element for text escaping)
             if cloned_target.text is not None:
-                tmp_element = etree.Element('t')
+                tmp_element = etree.Element("t")
                 tmp_element.text = cloned_target.text
-                target = data.forceunicode(etree.tostring(tmp_element, encoding='utf-8')[3:-4])
+                target = etree.tostring(tmp_element, encoding="unicode")[3:-4]
             else:
-                target = ''
+                target = ""
 
             # Include markup as well
-            target += ''.join([data.forceunicode(etree.tostring(child, encoding='utf-8'))
-                               for child in cloned_target.iterchildren()])
+            target += "".join(
+                [
+                    etree.tostring(child, encoding="unicode")
+                    for child in cloned_target.iterchildren()
+                ]
+            )
             return target
 
     def set_xml_text_plain(self, target, xmltarget):
@@ -302,23 +307,29 @@ class AndroidResourceUnit(base.TranslationUnit):
         xmltarget.text = self.escape(target)
 
     def set_xml_text_value(self, target, xmltarget):
-        if '<' in target or '&' in target:
+        if "<" in target or "&" in target:
             # Try to handle it as legacy XML
             parser = etree.XMLParser(strip_cdata=False, resolve_entities=False)
             if self._store is not None:
                 cloned_doc = copy.deepcopy(self._store.document)
                 cloned_root = cloned_doc.getroot()
                 cloned_root.clear()
-                template = etree.tostring(cloned_doc, encoding='unicode', doctype=copy.copy(self._store._doctype))
+                template = etree.tostring(
+                    cloned_doc,
+                    encoding="unicode",
+                    doctype=copy.copy(self._store._doctype),
+                )
             else:
-                template = '<resources></resources>'
-            if '</resources>' in template:
+                template = "<resources></resources>"
+            if "</resources>" in template:
                 match = "</resources>"
                 prefix = ""
             else:
                 match = "<resources/>"
                 prefix = "<resources>"
-            newstring = template.replace(match, f'{prefix}<string>{target}</string></resources>')
+            newstring = template.replace(
+                match, f"{prefix}<string>{target}</string></resources>"
+            )
             try:
                 newstring = etree.fromstring(newstring, parser)[0]
             except Exception:
@@ -349,8 +360,12 @@ class AndroidResourceUnit(base.TranslationUnit):
     def target(self):
         if self.xmlelement.tag != "plurals":
             return self.get_xml_text_value(self.xmlelement)
-        return multistring([data.forceunicode(self.get_xml_text_value(entry))
-                            for entry in self.xmlelement.iterchildren('item')])
+        return multistring(
+            [
+                self.get_xml_text_value(entry)
+                for entry in self.xmlelement.iterchildren("item")
+            ]
+        )
 
     @target.setter
     def target(self, target):
@@ -361,8 +376,8 @@ class AndroidResourceUnit(base.TranslationUnit):
                 self.xmlelement = etree.Element("plurals")
                 self.setid(old_id)
 
-            locale = self.gettargetlanguage().replace('_', '-').split('-')[0]
-            plural_tags = data.plural_tags.get(locale, data.plural_tags['en'])
+            locale = self.gettargetlanguage().replace("_", "-").split("-")[0]
+            plural_tags = data.plural_tags.get(locale, data.plural_tags["en"])
 
             # Get string list to handle, wrapping non multistring/list targets into a list.
             if isinstance(target, multistring):
@@ -374,8 +389,8 @@ class AndroidResourceUnit(base.TranslationUnit):
 
             # Sync plural_strings elements to plural_tags count.
             if len(plural_strings) < len(plural_tags):
-                plural_strings += [''] * (len(plural_tags) - len(plural_strings))
-            plural_strings = plural_strings[:len(plural_tags)]
+                plural_strings += [""] * (len(plural_tags) - len(plural_strings))
+            plural_strings = plural_strings[: len(plural_tags)]
 
             # Rebuild plurals.
             for entry in self.xmlelement.iterchildren():
@@ -412,39 +427,38 @@ class AndroidResourceUnit(base.TranslationUnit):
 
     # Notes are handled as previous sibling comments.
     def addnote(self, text, origin=None, position="append"):
-        if origin in ['programmer', 'developer', 'source code', None]:
+        if origin in ["programmer", "developer", "source code", None]:
             self.xmlelement.addprevious(etree.Comment(text))
         else:
-            return super().addnote(text, origin=origin, position=position)
+            super().addnote(text, origin=origin, position=position)
 
     def getnotes(self, origin=None):
-        if origin in ['programmer', 'developer', 'source code', None]:
+        if origin in ["programmer", "developer", "source code", None]:
             comments = []
             if self.xmlelement is not None:
                 prevSibling = self.xmlelement.getprevious()
-                while ((prevSibling is not None) and (prevSibling.tag is etree.Comment)):
+                while (prevSibling is not None) and (prevSibling.tag is etree.Comment):
                     comments.insert(0, prevSibling.text)
                     prevSibling = prevSibling.getprevious()
 
-            return '\n'.join(comments)
+            return "\n".join(comments)
         else:
             return super().getnotes(origin)
 
     def removenotes(self, origin=None):
-        if ((self.xmlelement is not None) and (self.xmlelement.getparent is not None)):
+        if (self.xmlelement is not None) and (self.xmlelement.getparent is not None):
             prevSibling = self.xmlelement.getprevious()
-            while ((prevSibling is not None) and (prevSibling.tag is etree.Comment)):
+            while (prevSibling is not None) and (prevSibling.tag is etree.Comment):
                 prevSibling.getparent().remove(prevSibling)
                 prevSibling = self.xmlelement.getprevious()
 
         super().removenotes()
 
     def __str__(self):
-        return etree.tostring(self.xmlelement, pretty_print=True,
-                              encoding='unicode')
+        return etree.tostring(self.xmlelement, pretty_print=True, encoding="unicode")
 
     def __eq__(self, other):
-        return (str(self) == str(other))
+        return str(self) == str(other)
 
     def hasplurals(self, thing):
         if isinstance(thing, multistring):
@@ -463,8 +477,8 @@ class AndroidResourceFile(lisa.LISAfile):
     Extensions = ["xml"]
     rootNode = "resources"
     bodyNode = "resources"
-    XMLskeleton = '''<?xml version="1.0" encoding="utf-8"?>
-<resources></resources>'''
+    XMLskeleton = """<?xml version="1.0" encoding="utf-8"?>
+<resources></resources>"""
     _doctype = None
 
     def initbody(self):
@@ -477,14 +491,19 @@ class AndroidResourceFile(lisa.LISAfile):
     def serialize(self, out=None):
         """Converts to a string containing the file's XML"""
         out.write(b'<?xml version="1.0" encoding="utf-8"?>\n')
-        reindent(self.document.getroot(), indent="    ", leaves=('string', 'item'))
-        self.document.write(out, pretty_print=False, xml_declaration=False,
-                            encoding='utf-8', doctype=self._doctype)
+        reindent(self.document.getroot(), indent="    ", leaves=("string", "item"))
+        self.document.write(
+            out,
+            pretty_print=False,
+            xml_declaration=False,
+            encoding="utf-8",
+            doctype=self._doctype,
+        )
 
     def parse(self, xml):
         """Populates this object from the given xml string"""
-        if not hasattr(self, 'filename'):
-            self.filename = getattr(xml, 'name', '')
+        if not hasattr(self, "filename"):
+            self.filename = getattr(xml, "name", "")
         if hasattr(xml, "read"):
             xml.seek(0)
             posrc = xml.read()
@@ -504,13 +523,13 @@ class AndroidResourceFile(lisa.LISAfile):
         target_lang = super().gettargetlanguage()
 
         # If targetlanguage isn't set, we try to extract it from the filename path (if any).
-        if target_lang is None and hasattr(self, 'filename') and self.filename:
+        if target_lang is None and hasattr(self, "filename") and self.filename:
             # Android standards expect resource files to be in a directory named "values[-<lang>[-r<region>]]".
             parent_dir = os.path.split(os.path.dirname(self.filename))[1]
-            match = re.search(r'^values-(\w*)', parent_dir)
+            match = re.search(r"^values-(\w*)", parent_dir)
             if match is not None:
                 target_lang = match.group(1)
-            elif parent_dir == 'values':
+            elif parent_dir == "values":
                 # If the resource file is inside the "values" directory, then it is the default/source language.
                 target_lang = self.sourcelanguage
 
@@ -547,8 +566,8 @@ class AndroidResourceFile(lisa.LISAfile):
                 cloned_doc = copy.deepcopy(unit._store.document)
                 cloned_doc.getroot().clear()
                 self._doctype = etree.tostring(
-                    cloned_doc, xml_declaration=False, encoding='unicode'
-                ).rsplit('\n', 1)[0]
+                    cloned_doc, xml_declaration=False, encoding="unicode"
+                ).rsplit("\n", 1)[0]
 
         super().addunit(unit, new)
         # Move aliased namespaces to the <resources> tag
