@@ -31,18 +31,17 @@ from translate.storage.workflow import StateEnum as states
 
 # Simple BOM based encoding detection
 ENCODING_BOMS = (
-    (codecs.BOM_UTF8, 'utf-8-sig'),
-    (codecs.BOM_UTF16, 'utf-16'),
-    (codecs.BOM_UTF16_BE, 'utf-16-be'),
-    (codecs.BOM_UTF16_LE, 'utf-16-le'),
-    (codecs.BOM_UTF32, 'utf-32'),
-    (codecs.BOM_UTF32_BE, 'utf-32-be'),
-    (codecs.BOM_UTF32_LE, 'utf-32-le'),
+    (codecs.BOM_UTF8, "utf-8-sig"),
+    (codecs.BOM_UTF16, "utf-16"),
+    (codecs.BOM_UTF16_BE, "utf-16-be"),
+    (codecs.BOM_UTF16_LE, "utf-16-le"),
+    (codecs.BOM_UTF32, "utf-32"),
+    (codecs.BOM_UTF32_BE, "utf-32-be"),
+    (codecs.BOM_UTF32_LE, "utf-32-le"),
 )
 
 
 class ParseError(Exception):
-
     def __init__(self, inner_exc):
         self.inner_exc = inner_exc
 
@@ -133,7 +132,11 @@ class TranslationUnit:
         :return: Returns *True* if the supplied :class:`TranslationUnit`
                  equals this unit.
         """
-        return self.source == other.source and self.target == other.target and self.getid() == other.getid()
+        return (
+            self.source == other.source
+            and self.target == other.target
+            and self.getid() == other.getid()
+        )
 
     def __ne__(self, other):
         return not self.__eq__(other)
@@ -144,9 +147,13 @@ class TranslationUnit:
     def __str__(self):
         """Converts to a string representation. Most often overriden by subclasses."""
         # no point in showing store object.
-        return ", ".join([
-            "%s: %s" % (k, self.__dict__[k]) for k in sorted(self.__dict__.keys()) if k != '_store'
-        ])
+        return ", ".join(
+            [
+                "{}: {}".format(k, self.__dict__[k])
+                for k in sorted(self.__dict__.keys())
+                if k != "_store"
+            ]
+        )
 
     @classmethod
     def rich_to_multistring(cls, elem_list):
@@ -203,12 +210,12 @@ class TranslationUnit:
 
     @rich_source.setter
     def rich_source(self, value):
-        if not hasattr(value, '__iter__'):
-            raise ValueError('value must be iterable')
+        if not hasattr(value, "__iter__"):
+            raise ValueError("value must be iterable")
         if len(value) < 1:
-            raise ValueError('value must have at least one element.')
+            raise ValueError("value must have at least one element.")
         if not isinstance(value[0], StringElem):
-            raise ValueError('value[0] must be of type StringElem.')
+            raise ValueError("value[0] must be of type StringElem.")
         self._rich_source = list(value)
         multi = self.rich_to_multistring(value)
         if self.source != multi:
@@ -225,12 +232,12 @@ class TranslationUnit:
 
     @rich_target.setter
     def rich_target(self, value):
-        if not hasattr(value, '__iter__'):
-            raise ValueError('value must be iterable')
+        if not hasattr(value, "__iter__"):
+            raise ValueError("value must be iterable")
         if len(value) < 1:
-            raise ValueError('value must have at least one element.')
+            raise ValueError("value must have at least one element.")
         if not isinstance(value[0], StringElem):
-            raise ValueError('value[0] must be of type StringElem.')
+            raise ValueError("value[0] must be of type StringElem.")
         self._rich_target = list(value)
         self.target = self.rich_to_multistring(value)
 
@@ -336,13 +343,13 @@ class TranslationUnit:
                        - 'developer', 'programmer', 'source code' (synonyms)
         """
         if position == "append" and getattr(self, "notes", None):
-            self.notes += '\n' + text
+            self.notes += "\n" + text
         else:
             self.notes = text
 
     def removenotes(self, origin=None):
         """Remove all the translator's notes."""
-        self.notes = ''
+        self.notes = ""
 
     def adderror(self, errorname, errortext):
         """Adds an error message to this unit.
@@ -423,7 +430,7 @@ class TranslationUnit:
 
     def hasplural(self):
         """Tells whether or not this specific unit has plural strings."""
-        #TODO: Reconsider
+        # TODO: Reconsider
         return False
 
     def getsourcelanguage(self):
@@ -432,8 +439,7 @@ class TranslationUnit:
     def gettargetlanguage(self):
         return self._store.gettargetlanguage()
 
-    def merge(self, otherunit, overwrite=False, comments=True,
-              authoritative=False):
+    def merge(self, otherunit, overwrite=False, comments=True, authoritative=False):
         """Do basic format agnostic merging."""
         if not self.target or overwrite:
             self.rich_target = otherunit.rich_target
@@ -475,7 +481,7 @@ class TranslationUnit:
             if state_range[0] <= n < state_range[1]:
                 return state_id
         if self.STATE:
-            raise ValueError('No state containing value %s' % (n))
+            raise ValueError("No state containing value %s" % (n))
         else:
             return n
 
@@ -496,8 +502,7 @@ class TranslationUnit:
 
 
 class TranslationStore:
-    """Base class for stores for multiple translation units of type UnitClass.
-    """
+    """Base class for stores for multiple translation units of type UnitClass."""
 
     UnitClass = TranslationUnit
     """The class of units that will be instantiated and used by this class"""
@@ -513,7 +518,7 @@ class TranslationStore:
     """Indicates if format can store suggestions and alternative translation
     for a unit"""
 
-    default_encoding = 'utf-8'
+    default_encoding = "utf-8"
     sourcelanguage = None
     targetlanguage = None
 
@@ -530,16 +535,16 @@ class TranslationStore:
     @property
     def encoding(self):
         # self._encoding is either defined by __init__ or auto-detected from parsed file
-        if self._encoding == 'auto':
-            return 'utf-8'
+        if self._encoding == "auto":
+            return "utf-8"
         return self._encoding or self.default_encoding
 
     @encoding.setter
     def encoding(self, value):
         if value == "CHARSET" or value is None:
             return
-        if value == 'ascii':
-            value = 'utf-8'
+        if value == "ascii":
+            value = "utf-8"
         self._encoding = value
 
     def getsourcelanguage(self):
@@ -560,7 +565,7 @@ class TranslationStore:
 
     def getprojectstyle(self):
         """Get the project type for this store."""
-        return getattr(self, '_project_style', None)
+        return getattr(self, "_project_style", None)
 
     def setprojectstyle(self, project_style):
         """Set the project type for this store."""
@@ -568,8 +573,7 @@ class TranslationStore:
 
     def unit_iter(self):
         """Iterator over all the units in this store."""
-        for unit in self.units:
-            yield unit
+        yield from self.units
 
     def getunits(self):
         """Return a list of all units in this store."""
@@ -651,7 +655,7 @@ class TranslationStore:
             if source in self.sourceindex:
                 self.sourceindex[source].remove(unit)
                 if len(self.sourceindex[source]) == 0:
-                    del(self.sourceindex[source])
+                    del self.sourceindex[source]
 
         if unit.hasplural():
             for source in unit.source.strings:
@@ -660,10 +664,12 @@ class TranslationStore:
             remove_source(unit.source)
 
         for location in unit.getlocations():
-            if (location in self.locationindex and
-                self.locationindex[location] is not None and
-                self.locationindex[location] == unit):
-                del(self.locationindex[location])
+            if (
+                location in self.locationindex
+                and self.locationindex[location] is not None
+                and self.locationindex[location] == unit
+            ):
+                del self.locationindex[location]
 
     def add_unit_to_index(self, unit):
         """Add a unit to source and location idexes"""
@@ -684,7 +690,7 @@ class TranslationStore:
         for location in unit.getlocations():
             # If locations aren't unique, keep the first unit.
             if location not in self.locationindex:
-                #FIXME: maybe better store a list of units like sourceindex in
+                # FIXME: maybe better store a list of units like sourceindex in
                 # case there are several units with the same location.
                 self.locationindex[location] = unit
 
@@ -713,7 +719,7 @@ class TranslationStore:
     def __getstate__(self):
         odict = self.__dict__.copy()
         # fileobj is generally not picklable
-        odict['fileobj'] = None
+        odict["fileobj"] = None
         return odict
 
     def __bytes__(self):
@@ -765,10 +771,7 @@ class TranslationStore:
         """
         for bom, encoding in ENCODING_BOMS:
             if text.startswith(bom):
-                return {
-                    'encoding': encoding,
-                    'confidence': 1.0
-                }
+                return {"encoding": encoding, "confidence": 1.0}
         return None
 
     def detect_encoding(self, text, default_encodings=None):
@@ -777,7 +780,7 @@ class TranslationStore:
         or by trying to decode the file.
         """
         if not default_encodings:
-            default_encodings = ['utf-8']
+            default_encodings = ["utf-8"]
         try:
             import chardet
         except ImportError:
@@ -785,37 +788,40 @@ class TranslationStore:
         else:
             # many false complaints with ellipse (…) (see bug 1825)
             detected_encoding = chardet.detect(text.replace(b"\xe2\x80\xa6", b""))
-            if detected_encoding['confidence'] < 0.48:
+            if detected_encoding["confidence"] < 0.48:
                 detected_encoding = None
-            elif detected_encoding['encoding'] == 'ascii':
-                detected_encoding['encoding'] = self.encoding
+            elif detected_encoding["encoding"] == "ascii":
+                detected_encoding["encoding"] = self.encoding
             else:
-                detected_encoding['encoding'] = detected_encoding['encoding'].lower()
+                detected_encoding["encoding"] = detected_encoding["encoding"].lower()
 
         encodings = []
         # Purposefully accessed the internal _encoding, as encoding is never 'auto'
-        if self._encoding == 'auto':
-            if detected_encoding and detected_encoding['encoding'] not in encodings:
-                encodings.append(detected_encoding['encoding'])
+        if self._encoding == "auto":
+            if detected_encoding and detected_encoding["encoding"] not in encodings:
+                encodings.append(detected_encoding["encoding"])
             for encoding in default_encodings:
                 if encoding not in encodings:
                     encodings.append(encoding)
         elif detected_encoding:
-            if '-' in detected_encoding['encoding']:
-                encoding, suffix = detected_encoding['encoding'].rsplit('-', 1)
+            if "-" in detected_encoding["encoding"]:
+                encoding, suffix = detected_encoding["encoding"].rsplit("-", 1)
             else:
-                encoding = detected_encoding['encoding']
+                encoding = detected_encoding["encoding"]
                 suffix = None
 
             # Different charset, just with BOM
-            if encoding == self.encoding and suffix == 'sig':
-                encodings.append(detected_encoding['encoding'])
-            elif detected_encoding['encoding'] != self.encoding:
-                logging.warning("trying to parse %s with encoding: %s but "
-                                "detected encoding is %s (confidence: %s)",
-                                self.filename, self.encoding,
-                                detected_encoding['encoding'],
-                                detected_encoding['confidence'])
+            if encoding == self.encoding and suffix == "sig":
+                encodings.append(detected_encoding["encoding"])
+            elif detected_encoding["encoding"] != self.encoding:
+                logging.warning(
+                    "trying to parse %s with encoding: %s but "
+                    "detected encoding is %s (confidence: %s)",
+                    self.filename,
+                    self.encoding,
+                    detected_encoding["encoding"],
+                    detected_encoding["confidence"],
+                )
             encodings.append(self.encoding)
         else:
             encodings.append(self.encoding)
@@ -828,8 +834,8 @@ class TranslationStore:
             except UnicodeDecodeError:
                 r_text = None
                 r_encoding = None
-        if r_encoding == 'ascii':
-            r_encoding = 'utf-8'
+        if r_encoding == "ascii":
+            r_encoding = "utf-8"
         return r_text, r_encoding
 
     def parse(self, data):
@@ -839,26 +845,24 @@ class TranslationStore:
     def savefile(self, storefile):
         """Write the string representation to the given file (or filename)."""
         if isinstance(storefile, str):
-            storefile = open(storefile, 'wb')
+            storefile = open(storefile, "wb")
         self.fileobj = storefile
         self._assignname()
         self.serialize(storefile)
         storefile.close()
 
     def save(self):
-        """Save to the file that data was originally read from, if available.
-        """
+        """Save to the file that data was originally read from, if available."""
         fileobj = getattr(self, "fileobj", None)
         if not fileobj:
             if hasattr(self, "filename"):
-                fileobj = open(self.filename, 'wb')
+                fileobj = open(self.filename, "wb")
         else:
             fileobj.close()
-            filename = getattr(fileobj, "name",
-                               getattr(fileobj, "filename", None))
+            filename = getattr(fileobj, "name", getattr(fileobj, "filename", None))
             if not filename:
                 raise ValueError("No file or filename to save to")
-            fileobj = open(filename, 'wb')
+            fileobj = open(filename, "wb")
         self.savefile(fileobj)
 
     @classmethod
@@ -867,9 +871,9 @@ class TranslationStore:
         to an object.
         """
         if isinstance(storefile, str):
-            storefile = open(storefile, 'rb')
-        mode = getattr(storefile, "mode", 'rb')
-        #For some reason GzipFile returns 1, so we have to test for that here
+            storefile = open(storefile, "rb")
+        mode = getattr(storefile, "mode", "rb")
+        # For some reason GzipFile returns 1, so we have to test for that here
         if mode == 1 or "r" in mode:
             storestring = storefile.read()
             storefile.close()
@@ -900,17 +904,18 @@ class UnitId:
 
     def __str__(self):
         def fmt(element, key):
-            if element == 'key':
-                return '{}{}'.format(self.KEY_SEPARATOR, key)
-            elif element == 'index':
-                return '{}[{}]'.format(self.INDEX_SEPARATOR, key)
+            if element == "key":
+                return f"{self.KEY_SEPARATOR}{key}"
+            elif element == "index":
+                return f"{self.INDEX_SEPARATOR}[{key}]"
             else:
-                raise ValueError('Unsupported element: {}'.format(element))
-        return ''.join([fmt(*part) for part in self.parts])
+                raise ValueError(f"Unsupported element: {element}")
+
+        return "".join([fmt(*part) for part in self.parts])
 
     def __add__(self, other):
         if not isinstance(other, list):
-            raise ValueError('Not supported type for add: {}'.format(type(other)))
+            raise ValueError("Not supported type for add: {}".format(type(other)))
         return self.__class__(self.parts + other)
 
     @classmethod
@@ -918,11 +923,11 @@ class UnitId:
         result = []
         # Strip possible leading separator
         if text.startswith(cls.KEY_SEPARATOR):
-            text = text[len(cls.KEY_SEPARATOR):]
+            text = text[len(cls.KEY_SEPARATOR) :]
         for item in text.split(cls.KEY_SEPARATOR):
-            if '[' in item and item[-1] == ']':
-                item, pos = item[:-1].split('[')
-                if cls.INDEX_SEPARATOR and item:
+            if "[" in item and item[-1] == "]":
+                item, pos = item[:-1].split("[")
+                if item:
                     result.append(("key", item))
                 result.append(("index", int(pos)))
             else:
@@ -945,26 +950,26 @@ class DictUnit(TranslationUnit):
         parts = self._unitid.parts
         for pos, part in enumerate(parts[:-1]):
             element, key = part
-            default = [] if parts[pos + 1][0] == 'index' else self.DefaultDict()
-            if element == 'index':
-                if len(target) <= key and not unset:
-                    target.append(default)
-            elif element == 'key':
+            default = [] if parts[pos + 1][0] == "index" else self.DefaultDict()
+            if element == "index":
+                while len(target) <= key and not unset:
+                    target.append(default.copy())
+            elif element == "key":
                 if key not in target or isinstance(target[key], str):
                     target[key] = default
             else:
-                raise ValueError('Unsupported element: {}'.format(element))
+                raise ValueError(f"Unsupported element: {element}")
             target = target[key]
         if override_key:
-            element, key = 'key', override_key
+            element, key = "key", override_key
         else:
             element, key = parts[-1]
-        if element == 'key':
+        if element == "key":
             if unset:
                 del target[key]
             else:
                 target[key] = value
-        elif element == 'index':
+        elif element == "index":
             if len(target) <= key:
                 if not unset:
                     target.append(value)
@@ -974,7 +979,7 @@ class DictUnit(TranslationUnit):
                 else:
                     target[key] = value
         else:
-            raise ValueError('Unsupported element: {}'.format(element))
+            raise ValueError(f"Unsupported element: {element}")
 
     def storevalues(self, output):
         self.storevalue(output, self.value)
@@ -991,6 +996,10 @@ class DictUnit(TranslationUnit):
 
 
 class DictStore(TranslationStore):
+    def get_root_node(self):
+        if self.units and self.units[0].getid().startswith("["):
+            return []
+        return OrderedDict()
 
     def serialize_units(self, output):
         for unit in self.unit_iter():
