@@ -29,7 +29,7 @@ from translate.storage.base import ParseError
 
 # Override the piclose tag from simple > to ?> otherwise we consume HTML
 # within the processing instructions
-html.parser.piclose = re.compile(r'\?>')
+html.parser.piclose = re.compile(r"\?>")
 
 
 class htmlunit(base.TranslationUnit):
@@ -55,12 +55,18 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
         "aside",
         "blockquote",
         "caption",
-        "dd", "dt",
+        "dd",
+        "dt",
         "div",
         "figcaption",
         "footer",
         "header",
-        "h1", "h2", "h3", "h4", "h5", "h6",
+        "h1",
+        "h2",
+        "h3",
+        "h4",
+        "h5",
+        "h6",
         "li",
         "main",
         "nav",
@@ -68,8 +74,9 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
         "p",
         "pre",
         "section",
-        "td", "th",
-        "title"
+        "td",
+        "th",
+        "title",
     ]
     """These HTML elements (tags) will be extracted as translation units, unless
     they lack translatable text content.
@@ -77,20 +84,17 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
     unit will be split into the parts before and after the inner translation unit."""
 
     TRANSLATABLE_ATTRIBUTES = [
-        "abbr",       # abbreviation for a table header cell
+        "abbr",  # abbreviation for a table header cell
         "alt",
-        "lang",       # only for the html element -- see extract_translatable_attributes()
+        "lang",  # only for the html element -- see extract_translatable_attributes()
         "summary",
-        "title",      # tooltip text for an element
-        "value"
+        "title",  # tooltip text for an element
+        "value",
     ]
     """Text from these HTML attributes will be extracted as translation units.
     Note: the content attribute of meta tags is a special case."""
 
-    TRANSLATABLE_METADATA = [
-        "description",
-        "keywords"
-    ]
+    TRANSLATABLE_METADATA = ["description", "keywords"]
     """Document metadata from meta elements with these names will be extracted as translation units.
     Reference `<https://developer.mozilla.org/en-US/docs/Web/HTML/Element/meta/name>`_"""
 
@@ -108,7 +112,7 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
         "param",
         "source",
         "track",
-        "wbr"
+        "wbr",
     ]
     """An empty element is an element that cannot have any child nodes (i.e., nested
     elements or text nodes). In HTML, using a closing tag on an empty element is
@@ -121,24 +125,25 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
 
     TRAILING_WHITESPACE_RE = re.compile(r"(\s+)$")
 
-    ENCODING_RE = re.compile(br'''<meta.*
+    ENCODING_RE = re.compile(
+        br"""<meta.*
                                 content.*=.*?charset.*?=\s*?
                                 ([^\s]*)
                                 \s*?["']\s*?>
-                             ''', re.VERBOSE | re.IGNORECASE)
+                             """,
+        re.VERBOSE | re.IGNORECASE,
+    )
 
-    def __init__(self, includeuntaggeddata=None, inputfile=None,
-                 callback=None):
+    def __init__(self, inputfile=None, callback=None):
         html.parser.HTMLParser.__init__(self, convert_charrefs=False)
         base.TranslationStore.__init__(self)
 
         # store parameters
-        self.filename = getattr(inputfile, 'name', None)
+        self.filename = getattr(inputfile, "name", None)
         if callback is None:
             self.callback = self._simple_callback
         else:
             self.callback = callback
-        self.includeuntaggeddata = includeuntaggeddata
 
         # initialize state
         self.filesrc = ""
@@ -162,7 +167,7 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
         """
         result = self.ENCODING_RE.findall(htmlsrc)
         if result:
-            self.encoding = result[0].decode('ascii')
+            self.encoding = result[0].decode("ascii")
         return self.encoding
 
     def do_encoding(self, htmlsrc):
@@ -181,8 +186,11 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
         self.emit_translation_unit()
         self.tu_content = []
         self.tu_location = "%s+%s:%d-%d" % (
-                           self.filename, ".".join(self.tag_path),
-                           self.getpos()[0], self.getpos()[1] + 1)
+            self.filename,
+            ".".join(self.tag_path),
+            self.getpos()[0],
+            self.getpos()[1] + 1,
+        )
 
     def end_translation_unit(self):
         # at the end of a translation unit:
@@ -198,7 +206,7 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
             self.tu_content.append(markup)
         else:
             self.emit_attribute_translation_units(markup)
-            self.filesrc += markup['html_content']
+            self.filesrc += markup["html_content"]
 
     def emit_translation_unit(self):
         # scan through the queue:
@@ -211,8 +219,10 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
         tagmap = {}
         tag = None
         for pos in range(len(self.tu_content)):
-            if self.tu_content[pos]['type'] != 'endtag' \
-                    and tag in self.EMPTY_HTML_ELEMENTS:
+            if (
+                self.tu_content[pos]["type"] != "endtag"
+                and tag in self.EMPTY_HTML_ELEMENTS
+            ):
                 match = tagstack.pop()
                 tag = None
 
@@ -220,10 +230,10 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
                 if end == 0:
                     start = pos
                 end = pos + 1
-            elif self.tu_content[pos]['type'] == 'starttag':
+            elif self.tu_content[pos]["type"] == "starttag":
                 tagstack.append(pos)
-                tag = self.tu_content[pos]['tag']
-            elif self.tu_content[pos]['type'] == 'endtag':
+                tag = self.tu_content[pos]["tag"]
+            elif self.tu_content[pos]["type"] == "endtag":
                 if tagstack:
                     match = tagstack.pop()
                     tagmap[match] = pos
@@ -235,71 +245,78 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
         if end == 0:
             for markup in self.tu_content:
                 self.emit_attribute_translation_units(markup)
-                self.filesrc += markup['html_content']
+                self.filesrc += markup["html_content"]
             return
 
         # scan the start and end tags captured between translatable content;
         # extend the captured interval to include the matching tags
         for pos in range(start + 1, end - 1):
-            if (self.tu_content[pos]['type'] == 'starttag' or
-                    self.tu_content[pos]['type'] == 'endtag') and \
-                    pos in tagmap:
+            if (
+                self.tu_content[pos]["type"] == "starttag"
+                or self.tu_content[pos]["type"] == "endtag"
+            ) and pos in tagmap:
                 match = tagmap[pos]
                 start = min(start, match)
                 end = max(end, match + 1)
 
         # emit leading uncaptured markup elements
         for markup in self.tu_content[0:start]:
-            if markup['type'] != 'comment':
+            if markup["type"] != "comment":
                 self.emit_attribute_translation_units(markup)
-                self.filesrc += markup['html_content']
+                self.filesrc += markup["html_content"]
 
         # emit captured markup elements
         if start < end:
             html_content = ""
             for markup in self.tu_content[start:end]:
-                if markup['type'] != 'comment':
-                    if 'untranslated_html' in markup:
-                        html_content += markup['untranslated_html']
+                if markup["type"] != "comment":
+                    if "untranslated_html" in markup:
+                        html_content += markup["untranslated_html"]
                     else:
-                        html_content += markup['html_content']
+                        html_content += markup["html_content"]
             normalized_content = self.WHITESPACE_RE.sub(" ", html_content.strip())
             assert normalized_content  # shouldn't be here otherwise
 
             unit = self.addsourceunit(normalized_content)
             unit.addlocation(self.tu_location)
-            comments = [markup['note'] for markup in self.tu_content
-                        if markup['type'] == 'comment']
+            comments = [
+                markup["note"]
+                for markup in self.tu_content
+                if markup["type"] == "comment"
+            ]
             if comments:
                 unit.addnote("\n".join(comments))
 
-            html_content = self.get_leading_whitespace(html_content) + \
-                self.callback(normalized_content) + \
-                self.get_trailing_whitespace(html_content)
+            html_content = (
+                self.get_leading_whitespace(html_content)
+                + self.callback(normalized_content)
+                + self.get_trailing_whitespace(html_content)
+            )
             self.filesrc += html_content
 
         # emit trailing uncaptured markup elements
-        for markup in self.tu_content[end:len(self.tu_content)]:
-            if markup['type'] != 'comment':
+        for markup in self.tu_content[end : len(self.tu_content)]:
+            if markup["type"] != "comment":
                 self.emit_attribute_translation_units(markup)
-                self.filesrc += markup['html_content']
+                self.filesrc += markup["html_content"]
 
     @staticmethod
     def has_translatable_content(markup):
         # processing instructions count as translatable content, because PHP
-        return markup['type'] in {'data', 'pi'} \
-            and markup['html_content'].strip()
+        return markup["type"] in {"data", "pi"} and markup["html_content"].strip()
 
     def extract_translatable_attributes(self, tag, attrs):
         result = []
-        if tag == 'meta':
+        if tag == "meta":
             tu = self.create_metadata_attribute_tu(attrs)
             if tu:
                 result.append(tu)
         else:
             for attrname, attrvalue in attrs:
-                if attrname in self.TRANSLATABLE_ATTRIBUTES \
-                        and self.translatable_attribute_matches_tag(attrname, tag):
+                if (
+                    attrname in self.TRANSLATABLE_ATTRIBUTES
+                    and self.translatable_attribute_matches_tag(attrname, tag)
+                ):
                     tu = self.create_attribute_tu(attrname, attrvalue)
                     if tu:
                         result.append(tu)
@@ -307,31 +324,34 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
 
     def create_metadata_attribute_tu(self, attrs):
         attrs_dict = dict(attrs)
-        name = attrs_dict['name'].lower() if 'name' in attrs_dict else None
-        if name in self.TRANSLATABLE_METADATA and 'content' in attrs_dict:
-            return self.create_attribute_tu('content', attrs_dict['content'])
+        name = attrs_dict["name"].lower() if "name" in attrs_dict else None
+        if name in self.TRANSLATABLE_METADATA and "content" in attrs_dict:
+            return self.create_attribute_tu("content", attrs_dict["content"])
 
     def translatable_attribute_matches_tag(self, attrname, tag):
-        if attrname == 'lang':
-            return tag == 'html'
+        if attrname == "lang":
+            return tag == "html"
         return True
 
     def create_attribute_tu(self, attrname, attrvalue):
         normalized_value = self.WHITESPACE_RE.sub(" ", attrvalue).strip()
         if normalized_value:
             return {
-                'html_content': normalized_value,
-                'location': "%s+%s:%d-%d" % (
-                            self.filename,
-                            ".".join(self.tag_path) + '[' + attrname + ']',
-                            self.getpos()[0], self.getpos()[1] + 1)
+                "html_content": normalized_value,
+                "location": "%s+%s:%d-%d"
+                % (
+                    self.filename,
+                    ".".join(self.tag_path) + "[" + attrname + "]",
+                    self.getpos()[0],
+                    self.getpos()[1] + 1,
+                ),
             }
 
     def emit_attribute_translation_units(self, markup):
-        if 'attribute_tus' in markup:
-            for tu in markup['attribute_tus']:
-                unit = self.addsourceunit(tu['html_content'])
-                unit.addlocation(tu['location'])
+        if "attribute_tus" in markup:
+            for tu in markup["attribute_tus"]:
+                unit = self.addsourceunit(tu["html_content"])
+                unit.addlocation(tu["location"])
 
     def translate_attributes(self, attrs):
         result = []
@@ -351,12 +371,8 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
             if attrvalue is None:
                 attr_strings.append(" " + attrname)
             else:
-                attr_strings.append(' %s="%s"' % (attrname, attrvalue))
-        return "<%s%s%s>" % (
-            tag,
-            "".join(attr_strings),
-            " /" if startend else ""
-        )
+                attr_strings.append(f' {attrname}="{attrvalue}"')
+        return "<{}{}{}>".format(tag, "".join(attr_strings), " /" if startend else "")
 
     def auto_close_empty_element(self):
         if self.tag_path and self.tag_path[-1] in self.EMPTY_HTML_ELEMENTS:
@@ -381,11 +397,11 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
 
         translated_attrs = self.translate_attributes(attrs)
         markup = {
-            'type': 'starttag',
-            'tag': tag,
-            'html_content': self.create_start_tag(tag, translated_attrs),
-            'untranslated_html': self.create_start_tag(tag, attrs),
-            'attribute_tus': self.extract_translatable_attributes(tag, attrs)
+            "type": "starttag",
+            "tag": tag,
+            "html_content": self.create_start_tag(tag, translated_attrs),
+            "untranslated_html": self.create_start_tag(tag, attrs),
+            "attribute_tus": self.extract_translatable_attributes(tag, attrs),
         }
         self.append_markup(markup)
 
@@ -393,19 +409,18 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
         try:
             popped = self.tag_path.pop()
         except IndexError:
-            raise ParseError("Mismatched tags: no more tags: line %s" %
-                             self.getpos()[0])
+            raise ParseError(
+                "Mismatched tags: no more tags: line %s" % self.getpos()[0]
+            )
         if popped != tag and popped in self.EMPTY_HTML_ELEMENTS:
             popped = self.tag_path.pop()
         if popped != tag:
-            raise ParseError("Mismatched closing tag: "
-                             "expected '%s' got '%s' at line %s" %
-                             (popped, tag, self.getpos()[0]))
+            raise ParseError(
+                "Mismatched closing tag: "
+                "expected '%s' got '%s' at line %s" % (popped, tag, self.getpos()[0])
+            )
 
-        self.append_markup({
-            'type': 'endtag',
-            'html_content': '</%s>' % tag
-        })
+        self.append_markup({"type": "endtag", "html_content": "</%s>" % tag})
 
         if tag in self.TRANSLATABLE_ELEMENTS:
             self.end_translation_unit()
@@ -421,10 +436,10 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
 
         translated_attrs = self.translate_attributes(attrs)
         markup = {
-            'type': 'startendtag',
-            'html_content': self.create_start_tag(tag, translated_attrs, startend=True),
-            'untranslated_html': self.create_start_tag(tag, attrs, startend=True),
-            'attribute_tus': self.extract_translatable_attributes(tag, attrs)
+            "type": "startendtag",
+            "html_content": self.create_start_tag(tag, translated_attrs, startend=True),
+            "untranslated_html": self.create_start_tag(tag, attrs, startend=True),
+            "attribute_tus": self.extract_translatable_attributes(tag, attrs),
         }
         self.append_markup(markup)
 
@@ -437,14 +452,11 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
 
     def handle_data(self, data):
         self.auto_close_empty_element()
-        self.append_markup({
-            'type': 'data',
-            'html_content': data
-        })
+        self.append_markup({"type": "data", "html_content": data})
 
     def handle_charref(self, name):
         """Handle entries in the form &#NNNN; e.g. &#8417;"""
-        if name.lower().startswith('x'):
+        if name.lower().startswith("x"):
             self.handle_data(chr(int(name[1:], 16)))
         else:
             self.handle_data(chr(int(name)))
@@ -452,39 +464,28 @@ class htmlfile(html.parser.HTMLParser, base.TranslationStore):
     def handle_entityref(self, name):
         """Handle named entities of the form &aaaa; e.g. &rsquo;"""
         converted = html5.get(name + ";", None)
-        if name in ['gt', 'lt', 'amp'] or not converted:
+        if name in ["gt", "lt", "amp"] or not converted:
             self.handle_data("&%s;" % name)
         else:
             self.handle_data(converted)
 
     def handle_comment(self, data):
         self.auto_close_empty_element()
-        self.append_markup({
-            'type': 'comment',
-            'html_content': "<!--%s-->" % data,
-            'note': data
-        })
+        self.append_markup(
+            {"type": "comment", "html_content": "<!--%s-->" % data, "note": data}
+        )
 
     def handle_decl(self, decl):
         self.auto_close_empty_element()
-        self.append_markup({
-            'type': 'decl',
-            'html_content': "<!%s>" % decl
-        })
+        self.append_markup({"type": "decl", "html_content": "<!%s>" % decl})
 
     def handle_pi(self, data):
         self.auto_close_empty_element()
-        self.append_markup({
-            'type': 'pi',
-            'html_content': "<?%s?>" % data
-        })
+        self.append_markup({"type": "pi", "html_content": "<?%s?>" % data})
 
     def unknown_decl(self, data):
         self.auto_close_empty_element()
-        self.append_markup({
-            'type': 'cdecl',
-            'html_content': "<![%s]>" % data
-        })
+        self.append_markup({"type": "cdecl", "html_content": "<![%s]>" % data})
 
 
 class POHTMLParser(htmlfile):
