@@ -32,7 +32,6 @@ comments.
 
 import os
 import re
-import struct
 import warnings
 from io import BytesIO
 
@@ -41,18 +40,12 @@ from translate.misc import quote, wStringIO
 
 # File normalisation
 
-normalfilenamechars = b"/#.0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
-normalizetable = b""
-int2byte = struct.Struct(">B").pack
-for i in map(int2byte, range(256)):
-    if i in normalfilenamechars:
-        normalizetable += i
-    else:
-        normalizetable += b"_"
+normalfilenamechars = (
+    b"/#.0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
+)
 
 
-class unormalizechar(dict):
-
+class normalizechar(dict):
     def __init__(self, normalchars):
         self.normalchars = {}
         for char in normalchars:
@@ -62,15 +55,12 @@ class unormalizechar(dict):
         return self.normalchars.get(key, "_")
 
 
-unormalizetable = unormalizechar(normalfilenamechars.decode("ascii"))
+normalizetable = normalizechar(normalfilenamechars.decode("ascii"))
 
 
 def normalizefilename(filename):
     """converts any non-alphanumeric (standard roman) characters to _"""
-    if isinstance(filename, bytes):
-        return filename.translate(normalizetable)
-    else:
-        return filename.translate(unormalizetable)
+    return filename.translate(normalizetable)
 
 
 def makekey(ookey, long_keys):
@@ -84,11 +74,11 @@ def makekey(ookey, long_keys):
     :return: unique ascii identifier
     """
     project, sourcefile, resourcetype, groupid, localid, platform = ookey
-    sourcefile = sourcefile.replace('\\', '/')
+    sourcefile = sourcefile.replace("\\", "/")
     if long_keys:
-        sourcebase = '/'.join((project, sourcefile))
+        sourcebase = "/".join((project, sourcefile))
     else:
-        sourceparts = sourcefile.split('/')
+        sourceparts = sourcefile.split("/")
         sourcebase = "".join(sourceparts[-1:])
     if len(groupid) == 0 or len(localid) == 0:
         fullid = groupid + localid
@@ -96,9 +86,10 @@ def makekey(ookey, long_keys):
         fullid = groupid + "." + localid
     if resourcetype:
         fullid = fullid + "." + resourcetype
-    key = "%s#%s" % (sourcebase, fullid)
+    key = f"{sourcebase}#{fullid}"
     return normalizefilename(key)
 
+
 # These are functions that deal with escaping and unescaping of the text fields
 # of the SDF file. These should only be applied to the text column.
 # The fields quickhelptext and title are assumed to carry no escaping.
@@ -127,11 +118,16 @@ def escape_text(text):
 
 def unescape_text(text):
     """Unescapes SDF text to be suitable for unit consumption."""
-    return text.replace("\\\\", "\a").replace("\\n", "\n").replace("\\t", "\t") \
-        .replace("\\r", "\r").replace("\a", "\\\\")
+    return (
+        text.replace("\\\\", "\a")
+        .replace("\\n", "\n")
+        .replace("\\t", "\t")
+        .replace("\\r", "\r")
+        .replace("\a", "\\\\")
+    )
 
 
-helptagre = re.compile(r'''<[/]??[a-z_\-]+?(?:| +[a-z]+?=".*?") *[/]??>''')
+helptagre = re.compile(r"""<[/]??[a-z_\-]+?(?:| +[a-z]+?=".*?") *[/]??>""")
 
 
 def escape_help_text(text):
@@ -144,9 +140,20 @@ def escape_help_text(text):
     text = text.replace("\\", "\\\\")
     for tag in helptagre.findall(text):
         escapethistag = False
-        for escape_tag in ["ahelp", "link", "item", "emph", "defaultinline",
-                           "switchinline", "caseinline", "variable",
-                           "bookmark_value", "image", "embedvar", "alt"]:
+        for escape_tag in [
+            "ahelp",
+            "link",
+            "item",
+            "emph",
+            "defaultinline",
+            "switchinline",
+            "caseinline",
+            "variable",
+            "bookmark_value",
+            "image",
+            "embedvar",
+            "alt",
+        ]:
             if tag.startswith("<%s" % escape_tag) or tag == "</%s>" % escape_tag:
                 escapethistag = True
         if tag in ["<br/>", "<help-id-missing/>"]:
@@ -159,7 +166,12 @@ def escape_help_text(text):
 
 def unescape_help_text(text):
     """Unescapes normal text to be suitable for writing to the SDF file."""
-    return text.replace(r"\<", "<").replace(r"\>", ">").replace(r'\"', '"').replace(r"\\", "\\")
+    return (
+        text.replace(r"\<", "<")
+        .replace(r"\>", ">")
+        .replace(r"\"", '"')
+        .replace(r"\\", "\\")
+    )
 
 
 class ooline:
@@ -168,35 +180,76 @@ class ooline:
     def __init__(self, parts=None):
         """construct an ooline from its parts"""
         if parts is None:
-            self.project, self.sourcefile, self.dummy, self.resourcetype, \
-                self.groupid, self.localid, self.helpid, self.platform, \
-                self.width, self.languageid, self.text, self.helptext, \
-                self.quickhelptext, self.title, self.timestamp = [""] * 15
+            (
+                self.project,
+                self.sourcefile,
+                self.dummy,
+                self.resourcetype,
+                self.groupid,
+                self.localid,
+                self.helpid,
+                self.platform,
+                self.width,
+                self.languageid,
+                self.text,
+                self.helptext,
+                self.quickhelptext,
+                self.title,
+                self.timestamp,
+            ) = [""] * 15
         else:
             self.setparts(parts)
 
     def setparts(self, parts):
         """create a line from its tab-delimited parts"""
         if len(parts) != 15:
-            warnings.warn("oo line contains %d parts, it should contain 15: %r" %
-                          (len(parts), parts))
+            warnings.warn(
+                "oo line contains %d parts, it should contain 15: %r"
+                % (len(parts), parts)
+            )
             newparts = list(parts)
             if len(newparts) < 15:
                 newparts = newparts + [""] * (15 - len(newparts))
             else:
                 newparts = newparts[:15]
             parts = tuple(newparts)
-        self.project, self.sourcefile, self.dummy, self.resourcetype, \
-            self.groupid, self.localid, self.helpid, self.platform, \
-            self.width, self.languageid, self._text, self.helptext, \
-            self.quickhelptext, self.title, self.timestamp = parts
+        (
+            self.project,
+            self.sourcefile,
+            self.dummy,
+            self.resourcetype,
+            self.groupid,
+            self.localid,
+            self.helpid,
+            self.platform,
+            self.width,
+            self.languageid,
+            self._text,
+            self.helptext,
+            self.quickhelptext,
+            self.title,
+            self.timestamp,
+        ) = parts
 
     def getparts(self):
         """return a list of parts in this line"""
-        return (self.project, self.sourcefile, self.dummy, self.resourcetype,
-                self.groupid, self.localid, self.helpid, self.platform,
-                self.width, self.languageid, self._text, self.helptext,
-                self.quickhelptext, self.title, self.timestamp)
+        return (
+            self.project,
+            self.sourcefile,
+            self.dummy,
+            self.resourcetype,
+            self.groupid,
+            self.localid,
+            self.helpid,
+            self.platform,
+            self.width,
+            self.languageid,
+            self._text,
+            self.helptext,
+            self.quickhelptext,
+            self.title,
+            self.timestamp,
+        )
 
     def gettext(self):
         """Obtains the text column and handle escaping."""
@@ -211,6 +264,7 @@ class ooline:
             self._text = escape_help_text(text)
         else:
             self._text = escape_text(text)
+
     text = property(gettext, settext)
 
     def __str__(self):
@@ -224,8 +278,14 @@ class ooline:
 
     def getkey(self):
         """get the key that identifies the resource"""
-        return (self.project, self.sourcefile, self.resourcetype, self.groupid,
-                self.localid, self.platform)
+        return (
+            self.project,
+            self.sourcefile,
+            self.resourcetype,
+            self.groupid,
+            self.localid,
+            self.platform,
+        )
 
 
 class oounit:
@@ -263,7 +323,7 @@ class oofile:
     """this represents an entire .oo file"""
 
     UnitClass = oounit
-    encoding = 'utf-8'
+    encoding = "utf-8"
 
     def __init__(self, input=None):
         """constructs the oofile"""
@@ -291,7 +351,7 @@ class oofile:
     def parse(self, input):
         """parses lines and adds them to the file"""
         if not self.filename:
-            self.filename = getattr(input, 'name', '')
+            self.filename = getattr(input, "name", "")
         if hasattr(input, "read"):
             src = input.read()
             input.close()
@@ -320,9 +380,15 @@ class oofile:
         lines = []
         for oe in self.units:
             if len(oe.lines) > 2:
-                warnings.warn("contains %d lines (should be 2 at most): languages %r" % (len(oe.lines), oe.languages))
+                warnings.warn(
+                    "contains %d lines (should be 2 at most): languages %r"
+                    % (len(oe.lines), oe.languages)
+                )
                 oekeys = [line.getkey() for line in oe.lines]
-                warnings.warn("contains %d lines (should be 2 at most): keys %r" % (len(oe.lines), oekeys))
+                warnings.warn(
+                    "contains %d lines (should be 2 at most): keys %r"
+                    % (len(oe.lines), oekeys)
+                )
             oeline = oe.getoutput(skip_source, fallback_lang) + "\r\n"
             lines.append(oeline)
         return "".join(lines)
@@ -333,16 +399,16 @@ class oomultifile:
     files...
     """
 
-    encoding = 'utf-8'
+    encoding = "utf-8"
 
     def __init__(self, filename, mode=None, multifilestyle="single"):
         """initialises oomultifile from a seekable inputfile or writable outputfile"""
         self.filename = filename
         if mode is None:
             if os.path.exists(filename):
-                mode = 'r'
+                mode = "r"
             else:
-                mode = 'w'
+                mode = "w"
         self.mode = mode
         self.multifilestyle = multifilestyle
         self.multifilename = os.path.splitext(filename)[0]
@@ -383,8 +449,7 @@ class oomultifile:
 
     def __iter__(self):
         """iterates through the subfile names"""
-        for subfile in self.listsubfiles():
-            yield subfile
+        yield from self.listsubfiles()
 
     def __contains__(self, pathname):
         """checks if this pathname is a valid subfile"""
@@ -417,6 +482,7 @@ class oomultifile:
                 contents = contents.decode(self.encoding)
             self.multifile.write(contents)
             self.multifile.flush()
+
         outputfile = wStringIO.CatchStringOutput(onclose)
         outputfile.filename = subfile
         return outputfile
