@@ -25,9 +25,7 @@ import copy
 import logging
 import re
 import textwrap
-from itertools import chain
 
-from translate.lang import data
 from translate.misc import quote
 from translate.misc.multistring import multistring
 from translate.storage import pocommon, poparser
@@ -41,8 +39,8 @@ lsep = "\n#: "
 
 # general functions for quoting / unquoting po strings
 
-po_unescape_map = {"\\r": "\r", "\\t": "\t", '\\"': '"', '\\n': '\n', '\\\\': '\\'}
-po_escape_map = dict([(value, key) for (key, value) in po_unescape_map.items()])
+po_unescape_map = {"\\r": "\r", "\\t": "\t", '\\"': '"', "\\n": "\n", "\\\\": "\\"}
+po_escape_map = {value: key for (key, value) in po_unescape_map.items()}
 
 
 def splitlines(text):
@@ -58,20 +56,20 @@ def splitlines(text):
     """
     # Strip UTF-8 BOM if present. This file would not be accepted
     # by gettext, but some editors might create it, so better handle it.
-    if text[:3] == b'\xEF\xBB\xBF':
+    if text[:3] == b"\xEF\xBB\xBF":
         text = text[3:]
     # Find first newline
-    newline = b'\n'
-    msgid_pos = max(0, text.find(b'msgid'))
+    newline = b"\n"
+    msgid_pos = max(0, text.find(b"msgid"))
     for i, ch in enumerate(text[msgid_pos:]):
         # Iteration over bytes yields numbers in Python 3
-        if ch in ('\n', 10):
+        if ch in ("\n", 10):
             break
-        if ch in ('\r', 13):
-            if text[msgid_pos + i + 1] in ('\n', 10):
-                newline = b'\r\n'
+        if ch in ("\r", 13):
+            if text[msgid_pos + i + 1] in ("\n", 10):
+                newline = b"\r\n"
             else:
-                newline = b'\r'
+                newline = b"\r"
             break
 
     return [x + newline for x in text.split(newline)]
@@ -90,7 +88,7 @@ def escapeforpo(line):
     last_location = 0
     for location in special_locations:
         escaped_line.append(line[last_location:location])
-        escaped_line.append(po_escape_map[line[location:location+1]])
+        escaped_line.append(po_escape_map[line[location : location + 1]])
         last_location = location + 1
     escaped_line.append(line[last_location:])
     return "".join(escaped_line)
@@ -102,7 +100,7 @@ def unescapehandler(escape):
 
 class PoWrapper(textwrap.TextWrapper):
     wordsep_re = re.compile(
-        r'''
+        r"""
             (
             \s+|                                  # any whitespace
             [a-z0-9A-Z_-]+/|                      # nicely split long URLs
@@ -113,11 +111,17 @@ class PoWrapper(textwrap.TextWrapper):
             [^\s\w]*\w+[a-zA-Z]-(?=\w+[a-zA-Z])|  # hyphenated words
             (?<=[\w\!\"\'\&\.\,\?])-{2,}(?=\w)    # em-dash
             )
-        ''',
-        re.VERBOSE
+        """,
+        re.VERBOSE,
     )
 
-    def __init__(self, width=77, replace_whitespace=False, expand_tabs=False, drop_whitespace=False):
+    def __init__(
+        self,
+        width=77,
+        replace_whitespace=False,
+        expand_tabs=False,
+        drop_whitespace=False,
+    ):
         super().__init__(
             width=width,
             replace_whitespace=replace_whitespace,
@@ -127,8 +131,7 @@ class PoWrapper(textwrap.TextWrapper):
 
 
 def quoteforpo(text, wrapper_obj=None):
-    """Quotes the given text for a PO file, returning quoted and escaped lines
-    """
+    """Quotes the given text for a PO file, returning quoted and escaped lines"""
     if text is None:
         return []
     if wrapper_obj is None:
@@ -142,7 +145,11 @@ def quoteforpo(text, wrapper_obj=None):
 
     polines = []
     len_lines = len(lines)
-    if len_lines > 2 or (len_lines == 2 and lines[1]) or len(lines[0]) > wrapper_obj.width - 6:
+    if (
+        len_lines > 2
+        or (len_lines == 2 and lines[1])
+        or len(lines[0]) > wrapper_obj.width - 6
+    ):
         polines.append('""')
     for line in lines:
         lns = wrapper_obj.wrap(line)
@@ -177,8 +184,8 @@ def unescape(line):
         # everything leading up to the escape
         extracted.append(line[lastpos:pos])
         # the escaped sequence (consuming 2 characters)
-        extracted.append(unescapehandler(line[pos:pos+2]))
-        lastpos = pos+2
+        extracted.append(unescapehandler(line[pos : pos + 2]))
+        lastpos = pos + 2
 
     extracted.append(line[lastpos:])
     return "".join(extracted)
@@ -196,7 +203,7 @@ def extractstr(string):
     left = string.find('"')
     right = string.rfind('"')
     if right > -1:
-        return string[left:right+1]
+        return string[left : right + 1]
     return string[left:] + '"'
 
 
@@ -215,7 +222,7 @@ class pounit(pocommon.pounit):
 
     # Our homegrown way to indicate what must be copied in a shallow
     # fashion
-    __shallow__ = ['_store', 'wrapper']
+    __shallow__ = ["_store", "wrapper"]
 
     def __init__(self, source=None, wrapper=None, **kwargs):
         self.wrapper = wrapper
@@ -241,12 +248,13 @@ class pounit(pocommon.pounit):
             self.msgidcomments = []
 
     def _get_all_comments(self):
-        return [self.othercomments,
-                self.automaticcomments,
-                self.sourcecomments,
-                self.typecomments,
-                self.msgidcomments,
-                ]
+        return [
+            self.othercomments,
+            self.automaticcomments,
+            self.sourcecomments,
+            self.typecomments,
+            self.msgidcomments,
+        ]
 
     allcomments = property(_get_all_comments)
 
@@ -263,9 +271,6 @@ class pounit(pocommon.pounit):
     def _set_source_vars(self, source):
         msgid = None
         msgid_plural = None
-        if isinstance(source, bytes):
-            # Guessing utf-8, non-ascii encoded content should not reach this point
-            source = source.decode('utf-8')
         if isinstance(source, multistring):
             source = source.strings
         if isinstance(source, list):
@@ -303,6 +308,7 @@ class pounit(pocommon.pounit):
         :param source: an unescaped source string.
         """
         self.prev_msgid, self.prev_msgid_plural = self._set_source_vars(source)
+
     prev_source = property(_get_prev_source, _set_prev_source)
 
     @property
@@ -316,9 +322,6 @@ class pounit(pocommon.pounit):
     def target(self, target):
         """Sets the msgstr to the given (unescaped) value"""
         self._rich_target = None
-        if isinstance(target, bytes):
-            # Guessing utf-8, non-ascii encoded content should not reach this point
-            target = target.decode('utf-8')
         if self.hasplural():
             if isinstance(target, multistring):
                 target = target.strings
@@ -328,14 +331,19 @@ class pounit(pocommon.pounit):
             if len(target) == 1:
                 target = target[0]
             else:
-                raise ValueError("po msgid element has no plural but msgstr has %d elements (%s)" % (len(target), target))
+                raise ValueError(
+                    "po msgid element has no plural but msgstr has %d elements (%s)"
+                    % (len(target), target)
+                )
         templates = self.msgstr
         if isinstance(templates, list):
             templates = {0: templates}
         if isinstance(target, list):
-            self.msgstr = dict([(i, self.quote(target[i])) for i in range(len(target))])
+            self.msgstr = {i: self.quote(target[i]) for i in range(len(target))}
         elif isinstance(target, dict):
-            self.msgstr = dict([(i, self.quote(targetstring)) for i, targetstring in target.items()])
+            self.msgstr = {
+                i: self.quote(targetstring) for i, targetstring in target.items()
+            }
         else:
             self.msgstr = self.quote(target)
 
@@ -363,11 +371,15 @@ class pounit(pocommon.pounit):
         """
         if origin is None:
             comments = "".join([comment[2:] or "\n" for comment in self.othercomments])
-            comments += "".join([comment[3:] or "\n" for comment in self.automaticcomments])
+            comments += "".join(
+                [comment[3:] or "\n" for comment in self.automaticcomments]
+            )
         elif origin == "translator":
             comments = "".join([comment[2:] or "\n" for comment in self.othercomments])
         elif origin in ["programmer", "developer", "source code"]:
-            comments = "".join([comment[3:] or "\n" for comment in self.automaticcomments])
+            comments = "".join(
+                [comment[3:] or "\n" for comment in self.automaticcomments]
+            )
         else:
             raise ValueError("Comment type not valid")
         # Let's drop the last newline
@@ -381,7 +393,6 @@ class pounit(pocommon.pounit):
         # ignore empty strings and strings without non-space characters
         if not (text and text.strip()):
             return
-        text = data.forceunicode(text)
         commentlist = self.othercomments
         linestart = "#"
         autocomments = False
@@ -431,12 +442,16 @@ class pounit(pocommon.pounit):
 
     def _msgidlen(self):
         if self.hasplural():
-            return len(unquotefrompo(self.msgid)) + len(unquotefrompo(self.msgid_plural))
+            return len(unquotefrompo(self.msgid)) + len(
+                unquotefrompo(self.msgid_plural)
+            )
         return len(unquotefrompo(self.msgid))
 
     def _msgstrlen(self):
         if isinstance(self.msgstr, dict):
-            combinedstr = "\n".join(filter(None, [unquotefrompo(msgstr) for msgstr in self.msgstr.values()]))
+            combinedstr = "\n".join(
+                filter(None, [unquotefrompo(msgstr) for msgstr in self.msgstr.values()])
+            )
             return len(combinedstr)
         return len(unquotefrompo(self.msgstr))
 
@@ -448,16 +463,7 @@ class pounit(pocommon.pounit):
         """
 
         def mergelists(list1, list2, split=False):
-            # Decode where necessary (either all bytestrings or all unicode)
-            if any(isinstance(item, str) for item in chain(list1, list2)):
-                for position, item in enumerate(list1):
-                    if isinstance(item, bytes):
-                        list1[position] = item.decode("utf-8")
-                for position, item in enumerate(list2):
-                    if isinstance(item, bytes):
-                        list2[position] = item.decode("utf-8")
-
-            #Determine the newline style of list1
+            # Determine the newline style of list1
             lineend = ""
             if list1 and list1[0]:
                 for candidate in ["\n", "\r", "\n\r"]:
@@ -468,7 +474,7 @@ class pounit(pocommon.pounit):
             else:
                 lineend = "\n"
 
-            #Split if directed to do so:
+            # Split if directed to do so:
             if split:
                 splitlist1 = []
                 splitlist2 = []
@@ -479,9 +485,15 @@ class pounit(pocommon.pounit):
                 for item in list2:
                     splitlist2.extend(item.split()[1:])
                     prefix = item.split()[0]
-                list1.extend(["%s %s%s" % (prefix, item, lineend) for item in splitlist2 if item not in splitlist1])
+                list1.extend(
+                    [
+                        f"{prefix} {item}{lineend}"
+                        for item in splitlist2
+                        if item not in splitlist1
+                    ]
+                )
             else:
-                #Normal merge, but conform to list1 newline style
+                # Normal merge, but conform to list1 newline style
                 if list1 != list2:
                     for item in list2:
                         if lineend:
@@ -489,6 +501,7 @@ class pounit(pocommon.pounit):
                         # avoid duplicate comment lines (this might cause some problems)
                         if item not in list1 or len(item) < 5:
                             list1.append(item)
+
         if not isinstance(otherpo, pounit):
             super().merge(otherpo, overwrite, comments)
             return
@@ -505,9 +518,14 @@ class pounit(pocommon.pounit):
         if not self.istranslated() or overwrite:
             # Remove kde-style comments from the translation (if any).
             if self._extract_msgidcomments(otherpo.target):
-                otherpo.target = otherpo.target.replace('_: ' + otherpo._extract_msgidcomments() + '\n', '')
+                otherpo.target = otherpo.target.replace(
+                    "_: " + otherpo._extract_msgidcomments() + "\n", ""
+                )
             self.target = otherpo.target
-            if self.source != otherpo.source or self.getcontext() != otherpo.getcontext():
+            if (
+                self.source != otherpo.source
+                or self.getcontext() != otherpo.getcontext()
+            ):
                 self.markfuzzy()
             else:
                 self.markfuzzy(otherpo.isfuzzy())
@@ -519,17 +537,23 @@ class pounit(pocommon.pounit):
                 self.markfuzzy()
 
     def isheader(self):
-        #return (self._msgidlen() == 0) and (self._msgstrlen() > 0) and (len(self.msgidcomments) == 0)
-        #rewritten here for performance:
-        return (is_null(self.msgid)
-                and not is_null(self.msgstr)
-                and self.msgidcomments == []
-                and is_null(self.msgctxt))
+        # return (self._msgidlen() == 0) and (self._msgstrlen() > 0) and (len(self.msgidcomments) == 0)
+        # rewritten here for performance:
+        return (
+            is_null(self.msgid)
+            and not is_null(self.msgstr)
+            and self.msgidcomments == []
+            and is_null(self.msgctxt)
+        )
 
     def isblank(self):
         if self.isheader() or self.msgidcomments:
             return False
-        if (self._msgidlen() == 0) and (self._msgstrlen() == 0) and (is_null(self.msgctxt)):
+        if (
+            (self._msgidlen() == 0)
+            and (self._msgstrlen() == 0)
+            and (is_null(self.msgctxt))
+        ):
             return True
         return False
         # TODO: remove:
@@ -540,7 +564,7 @@ class pounit(pocommon.pounit):
         for tc in self.typecomments:
             for flag in tc.split(","):
                 value = flag.strip()
-                if not value or value == '#':
+                if not value or value == "#":
                     continue
                 yield value
 
@@ -580,7 +604,7 @@ class pounit(pocommon.pounit):
                 self.typecomments = []
 
     def isfuzzy(self):
-        return self.hastypecomment('fuzzy')
+        return self.hastypecomment("fuzzy")
 
     def markfuzzy(self, present=True):
         if present:
@@ -598,7 +622,7 @@ class pounit(pocommon.pounit):
         if self.obsolete:
             self.makeobsolete()
         else:
-            self.markfuzzy(self.hastypecomment('fuzzy'))
+            self.markfuzzy(self.hastypecomment("fuzzy"))
 
     def isobsolete(self):
         return self.obsolete
@@ -625,7 +649,14 @@ class pounit(pocommon.pounit):
     def _getmsgpartstr(self, partname, partlines, partcomments=""):
         if isinstance(partlines, dict):
             partkeys = sorted(partlines.keys())
-            return "".join([self._getmsgpartstr("%s[%d]" % (partname, partkey), partlines[partkey], partcomments) for partkey in partkeys])
+            return "".join(
+                [
+                    self._getmsgpartstr(
+                        "%s[%d]" % (partname, partkey), partlines[partkey], partcomments
+                    )
+                    for partkey in partkeys
+                ]
+            )
         partstr = [partname, " "]
         partstartline = 0
         if partlines and not partcomments:
@@ -634,7 +665,7 @@ class pounit(pocommon.pounit):
         elif partcomments:
             if partlines and not unquotefrompo(partlines[:1]):
                 # if there is a blank leader line, it must come before the comment
-                partstr.extend((partlines[0], '\n'))
+                partstr.extend((partlines[0], "\n"))
                 # but if the whole string is blank, leave it in
                 if len(partlines) > 1:
                     partstartline += 1
@@ -647,10 +678,10 @@ class pounit(pocommon.pounit):
                 for comment in partcomments:
                     comment = unquotefrompo([comment])
                     if comment.startswith("_:"):
-                        comment = comment[len("_:"):]
+                        comment = comment[len("_:") :]
                     if comment.endswith("\\n"):
-                        comment = comment[:-len("\\n")]
-                    #Before we used to strip. Necessary in some cases?
+                        comment = comment[: -len("\\n")]
+                    # Before we used to strip. Necessary in some cases?
                     combinedcomment.append(comment)
                 partcomments = self.quote("_:%s" % "".join(combinedcomment))
                 # Strip heading empty line for multiline string, it was already added above
@@ -660,7 +691,7 @@ class pounit(pocommon.pounit):
             partstr.append(quote.rstripeol("\n".join(partcomments)))
         else:
             partstr.append('""')
-        partstr.append('\n')
+        partstr.append("\n")
         # add the rest
         previous = None
         for partline in partlines[partstartline:]:
@@ -668,7 +699,7 @@ class pounit(pocommon.pounit):
             if previous == '""' and partline == '""':
                 continue
             previous = partline
-            partstr.extend((partline, '\n'))
+            partstr.extend((partline, "\n"))
         return "".join(partstr)
 
     def __str__(self):
@@ -680,13 +711,13 @@ class pounit(pocommon.pounit):
 
         def add_prev_msgid_lines(lines, prefix, header, var):
             if var:
-                lines.append("%s %s %s\n" % (prefix, header, var[0]))
-                lines.extend("%s %s\n" % (prefix, line) for line in var[1:])
+                lines.append("{} {} {}\n".format(prefix, header, var[0]))
+                lines.extend(f"{prefix} {line}\n" for line in var[1:])
 
         def add_prev_msgid_info(lines, prefix):
-            add_prev_msgid_lines(lines, prefix, 'msgctxt', self.prev_msgctxt)
-            add_prev_msgid_lines(lines, prefix, 'msgid', self.prev_msgid)
-            add_prev_msgid_lines(lines, prefix, 'msgid_plural', self.prev_msgid_plural)
+            add_prev_msgid_lines(lines, prefix, "msgctxt", self.prev_msgctxt)
+            add_prev_msgid_lines(lines, prefix, "msgid", self.prev_msgid)
+            add_prev_msgid_lines(lines, prefix, "msgid_plural", self.prev_msgid_plural)
 
         lines = []
         lines.extend(self.othercomments)
@@ -696,9 +727,15 @@ class pounit(pocommon.pounit):
             add_prev_msgid_info(obsoletelines, prefix="#~|")
             if self.msgctxt:
                 obsoletelines.append(self._getmsgpartstr("#~ msgctxt", self.msgctxt))
-            obsoletelines.append(self._getmsgpartstr("#~ msgid", self.msgid, self.msgidcomments))
+            obsoletelines.append(
+                self._getmsgpartstr("#~ msgid", self.msgid, self.msgidcomments)
+            )
             if self.msgid_plural or self.msgid_pluralcomments:
-                obsoletelines.append(self._getmsgpartstr("#~ msgid_plural", self.msgid_plural, self.msgid_pluralcomments))
+                obsoletelines.append(
+                    self._getmsgpartstr(
+                        "#~ msgid_plural", self.msgid_plural, self.msgid_pluralcomments
+                    )
+                )
             obsoletelines.append(self._getmsgpartstr("#~ msgstr", self.msgstr))
             for index, obsoleteline in enumerate(obsoletelines):
                 # We need to account for a multiline msgid or msgstr here
@@ -719,10 +756,13 @@ class pounit(pocommon.pounit):
             lines.append(self._getmsgpartstr("msgctxt", self.msgctxt))
         lines.append(self._getmsgpartstr("msgid", self.msgid, self.msgidcomments))
         if self.msgid_plural or self.msgid_pluralcomments:
-            lines.append(self._getmsgpartstr("msgid_plural", self.msgid_plural, self.msgid_pluralcomments))
+            lines.append(
+                self._getmsgpartstr(
+                    "msgid_plural", self.msgid_plural, self.msgid_pluralcomments
+                )
+            )
         lines.append(self._getmsgpartstr("msgstr", self.msgstr))
-        postr = "".join(lines)
-        return postr
+        return "".join(lines)
 
     def getlocations(self):
         """Get a list of locations from sourcecomments in the PO unit
@@ -745,7 +785,6 @@ class pounit(pocommon.pounit):
         :type location: String
 
         """
-        location = data.forceunicode(location)
         location = pocommon.quote_plus(location)
         self.sourcecomments.append("#: %s\n" % location)
 
@@ -759,7 +798,7 @@ class pounit(pocommon.pounit):
 
         if not text:
             text = unquotefrompo(self.msgidcomments)
-        return text.split('\n')[0].replace('_: ', '', 1)
+        return text.split("\n")[0].replace("_: ", "", 1)
 
     def setmsgidcomment(self, msgidcomment):
         if msgidcomment:
@@ -774,7 +813,6 @@ class pounit(pocommon.pounit):
         return unquotefrompo(self.msgctxt) + self._extract_msgidcomments()
 
     def setcontext(self, context):
-        context = data.forceunicode(context)
         self.msgctxt = self.quote(context)
 
     def getid(self):
@@ -784,12 +822,12 @@ class pounit(pocommon.pounit):
         # the msgid. For generation of .mo files, we might want to use this
         # code to generate the entry for the hash table, but for now, it is
         # commented out for conformance to gettext.
-#        id = '\0'.join(self.source.strings)
+        #        id = '\0'.join(self.source.strings)
         id = self.source
         if self.msgidcomments:
-            id = "_: %s\n%s" % (context, id)
+            id = f"_: {context}\n{id}"
         elif context:
-            id = "%s\04%s" % (context, id)
+            id = f"{context}\04{id}"
         return id
 
 
@@ -810,10 +848,10 @@ class pofile(pocommon.pofile):
 
     def parse(self, input):
         """Parses the given file or file source string."""
-        if hasattr(input, 'name'):
+        if hasattr(input, "name"):
             self.filename = input.name
-        elif not getattr(self, 'filename', ''):
-            self.filename = ''
+        elif not getattr(self, "filename", ""):
+            self.filename = ""
         if not isinstance(input, bytes):
             input = input.read()
         input = iter(splitlines(input))
@@ -836,6 +874,7 @@ class pofile(pocommon.pofile):
         def addcomment(thepo):
             thepo.msgidcomments.append('"_: %s\\n"' % " ".join(thepo.getlocations()))
             markedpos.append(thepo)
+
         for thepo in self.units:
             id = thepo.getid()
             if thepo.isheader() and not thepo.getlocations():
@@ -852,22 +891,29 @@ class pofile(pocommon.pofile):
                     origpo = id_dict[id]
                     if origpo not in markedpos and id:
                         # if it doesn't have an id, we already added msgctxt
-                        origpo.msgctxt.append('"%s"' % escapeforpo(" ".join(origpo.getlocations())))
+                        origpo.msgctxt.append(
+                            '"%s"' % escapeforpo(" ".join(origpo.getlocations()))
+                        )
                         markedpos.append(thepo)
-                    thepo.msgctxt.append('"%s"' % escapeforpo(" ".join(thepo.getlocations())))
+                    thepo.msgctxt.append(
+                        '"%s"' % escapeforpo(" ".join(thepo.getlocations()))
+                    )
                     if not thepo.msgctxt == id_dict[id].msgctxt:
                         uniqueunits.append(thepo)
                     else:
                         logger.warning(
                             "Duplicate unit found with msgctx of '%s' and source '%s'",
                             thepo.msgctxt,
-                            thepo.source)
+                            thepo.source,
+                        )
             else:
                 if not id:
                     if duplicatestyle == "merge":
                         addcomment(thepo)
                     else:
-                        thepo.msgctxt.append('"%s"' % escapeforpo(" ".join(thepo.getlocations())))
+                        thepo.msgctxt.append(
+                            '"%s"' % escapeforpo(" ".join(thepo.getlocations()))
+                        )
                 id_dict[id] = thepo
                 uniqueunits.append(thepo)
         self.units = uniqueunits
@@ -878,40 +924,18 @@ class pofile(pocommon.pofile):
         try:
             for unit in self.units:
                 if not at_start:
-                    out.write(b'\n')
+                    out.write(b"\n")
                 else:
                     at_start = False
                 out.write(unit._getoutput().encode(self.encoding))
         except UnicodeEncodeError:
-            if self.encoding == 'utf-8':
+            if self.encoding == "utf-8":
                 raise
             self.updateheader(add=True, Content_Type="text/plain; charset=UTF-8")
             self.encoding = "utf-8"
             out.seek(0)
             self.serialize(out)
 
-    def encode(self, lines):
-        """encode any unicode strings in lines in self.encoding"""
-        newlines = []
-        for line in lines:
-            if isinstance(line, str):
-                line = line.encode(self.encoding)
-            newlines.append(line)
-        return newlines
-
-    def decode(self, lines):
-        """decode any non-unicode strings in lines with self.encoding"""
-        newlines = []
-        for line in lines:
-            if isinstance(line, bytes):
-                try:
-                    line = line.decode(self.encoding)
-                except UnicodeDecodeError as e:
-                    raise UnicodeDecodeError("Error decoding line with encoding %r: %s. Line is %r" %
-                                             (self.encoding, e, line))
-            newlines.append(line)
-        return newlines
-
     def unit_iter(self):
         for unit in self.units:
             if not (unit.isheader() or unit.isobsolete()):
