@@ -21,7 +21,6 @@
 
 from lxml import etree
 
-from translate.lang import data
 from translate.misc.xml_helpers import reindent, setXMLspace
 from translate.storage import lisa
 from translate.storage.placeables import general
@@ -57,7 +56,7 @@ class RESXUnit(lisa.LISAunit):
         if targetnode is None:
             etree.SubElement(self.xmlelement, self.namespaced("value"))
             return None
-        return data.forceunicode(targetnode.text) or ""
+        return targetnode.text or ""
 
     @target.setter
     def target(self, target):
@@ -68,12 +67,10 @@ class RESXUnit(lisa.LISAunit):
             return
         targetnode = self._gettargetnode()
         targetnode.clear()
-        targetnode.text = data.forceunicode(target) or ""
+        targetnode.text = target or ""
 
     def addnote(self, text, origin=None, position="append"):
         """Add a note specifically in the appropriate "comment" tag"""
-        if isinstance(text, bytes):
-            text = text.decode("utf-8")
         current_notes = self.getnotes(origin)
         self.removenotes(origin)
         note = etree.SubElement(self.xmlelement, self.namespaced("comment"))
@@ -96,7 +93,7 @@ class RESXUnit(lisa.LISAunit):
         notenode = self.xmlelement.find(self.namespaced("comment"))
         if notenode is not None and notenode.text is not None:
             comments.append(notenode.text)
-        return '\n'.join(comments)
+        return "\n".join(comments)
 
     def removenotes(self, origin=None):
         note = self.xmlelement.find(self.namespaced("comment"))
@@ -104,9 +101,7 @@ class RESXUnit(lisa.LISAunit):
             self.xmlelement.remove(note)
 
     def setid(self, value):
-        if id is None:
-            return False
-        else:
+        if id is not None:
             self.xmlelement.set("name", value)
 
     def getid(self):
@@ -131,7 +126,7 @@ class RESXFile(lisa.LISAfile):
     rootNode = "root"
     # We will switch out .body to fit with the context we are working on
     bodyNode = ""
-    XMLskeleton = '''<?xml version="1.0" encoding="utf-8"?>
+    XMLskeleton = """<?xml version="1.0" encoding="utf-8"?>
 <root>
   <xsd:schema id="root" xmlns="" xmlns:xsd="http://www.w3.org/2001/XMLSchema" xmlns:msdata="urn:schemas-microsoft-com:xml-msdata">
     <xsd:import namespace="http://www.w3.org/XML/1998/namespace" />
@@ -192,8 +187,8 @@ class RESXFile(lisa.LISAfile):
     <value>System.Resources.ResXResourceWriter, System.Windows.Forms, Version=4.0.0.0, Culture=neutral, PublicKeyToken=b77a5c561934e089</value>
   </resheader>
 </root>
-'''
-    namespace = ''
+"""
+    namespace = ""
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -211,7 +206,7 @@ class RESXFile(lisa.LISAfile):
         setXMLspace(unit.xmlelement, "preserve")
         if unit.getid() is None:
             self._messagenum += 1
-            unit.setid("%s" % unit.source.strip(' '))
+            unit.setid("%s" % unit.source.strip(" "))
         # adjust the current and previous elements for new ones;
         # otherwise they will not be indented correctly.
         if new:
@@ -230,7 +225,8 @@ class RESXFile(lisa.LISAfile):
         reindent(root, indent="  ", max_level=4)
         # Use same header as Visual Studio
         out.write(b'<?xml version="1.0" encoding="utf-8"?>\n')
-        content = etree.tostring(root, pretty_print=False, xml_declaration=False,
-                                 encoding='utf-8')
+        content = etree.tostring(
+            root, pretty_print=False, xml_declaration=False, encoding="utf-8"
+        )
         # Additional space on empty tags same as Visual Studio
-        out.write(content.replace(b'/>', b' />'))
+        out.write(content.replace(b"/>", b" />"))
